<?php
/**
 * Jogasana Settings Options
 */

if ( !class_exists('jogasana_redux_settings') ) {

	class jogasana_redux_settings {

		public $args = array();
		public $sections = array();
		public $theme;
		public $version;
		public $ReduxFramework;

		public function __construct() {

			if ( !class_exists('ReduxFramework') ) {
				return;
			}

			$this->initSettings();

		}

		public function initSettings() {

			$this->theme = wp_get_theme();

			// Set the default arguments
			$this->setArguments();

			// Create the sections and fields
			$this->setSections();

			if ( !isset($this->args['opt_name']) ) { return; }

			$this->ReduxFramework = new ReduxFramework($this->sections, $this->args);

		}

		public function arrayNumber($from = 0, $to = 50, $step = 1, $array = array()) {
			for ($i = $from; $i <= $to; $i += $step) {
				$array[$i] = $i;
			}
			return $array;
		}

		public function setSections() {

			$page_wrapper = jogasana_options_wrapper();
			$page_layouts = jogasana_options_layouts();
			$sidebars = jogasana_options_sidebars();
			$header_type = jogasana_options_header_types();
			
			$this->sections[] = array(
				'icon' => 'el-icon-dashboard',
				'icon_class' => 'icon',
				'title' => esc_html__('General', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'show-loading-overlay',
						'type' => 'switch',
						'title' => esc_html__( 'Loading Overlay', 'jogasana' ),
						'default' => true,
						'on' => esc_html__('Show', 'jogasana'),
						'off' => esc_html__('Hide', 'jogasana'),
					),
					array(
						'id' => 'wrapper',
						'type' => 'image_select',
						'title' => esc_html__('Page Wrapper', 'jogasana'),
						'options' => $page_wrapper,
						'default' => 'ys-wide-layout-type'
					),
					array(
						'id' => 'page-layout',
						'type' => 'image_select',
						'title' => esc_html__('Page Layout', 'jogasana'),
						'options' => $page_layouts,
						'default' => 'ys-right-sidebar'
					),
					array(
						'id' => 'sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'jogasana'),
						'required' => array( 'page-layout','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'general-widget-area'
					),
					array(
						'id' => 'show-main-pagetitle',
						'type' => 'switch',
						'title' => esc_html__('Show Page Title', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => '101',
						'type' => 'info',
						'title' => esc_html__('Mailchimp api', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => "mailchimp-api",
						'type' => 'text',
						'title' => esc_html__('Enter your Mailchimp Api', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "mailchimp-id",
						'type' => 'text',
						'title' => esc_html__('Enter your Mailchimp Id', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "mailchimp-center",
						'type' => 'text',
						'title' => esc_html__('Enter your Mailchimp data center(e.g. us4)', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "mailchimp-success",
						'type' => 'text',
						'title' => esc_html__('Success Message', 'jogasana'),
						'default' => esc_html__('You\'ve been added to our sign-up list.', 'jogasana')
					),
					array(
						'id' => "mailchimp-error",
						'type' => 'text',
						'title' => esc_html__('Error Message', 'jogasana'),
						'default' => esc_html__('Error! You\'ve not been added to our sign-up list', 'jogasana')
					),
				)
			);

			// Logo
			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Logo', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'logo',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo.png')
						)
					),
					array(
						'id' => 'logo_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo HiDPI', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo@2x.png')
						)
					),
					array(
						'id' => 'logo2',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 2', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo2.png')
						)
					),
					array(
						'id' => 'logo2_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 2 HiDPI', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo2@2x.png')
						)
					),
					array(
						'id' => 'logo3',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 3', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo3.png')
						)
					),
					array(
						'id' => 'logo3_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 3 HiDPI', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo3@2x.png')
						)
					),
					array(
						'id' => 'logo4',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 4', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo4.png')
						)
					),
					array(
						'id' => 'logo4_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 4 HiDPI', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo4@2x.png')
						)
					),
					array(
						'id' => 'logo5',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 5', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo.png')
						)
					),
					array(
						'id' => 'logo5_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo Header 5 HiDPI', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo@2x.png')
						)
					),
					array(
						'id' => 'favicon',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Favicon', 'jogasana'),
						'default' => array(
							'url' => ''
						)
					)
				)
			);

			// Skin Styling
			$this->sections[] = array(
				'icon' => 'el-icon-broom',
				'icon_class' => 'icon',
				'title' => esc_html__('Skin', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'primary-color',
						'type' => 'color',
						'title' => esc_html__('Primary Color', 'jogasana'),
						'desc' => esc_html__('Color for button and other', 'jogasana'),
						'default' => '#45b29d',
						'validate' => 'color',
					),
					array(
						'id' => 'secondary-color',
						'type' => 'color',
						'title' => esc_html__('Secondary Color', 'jogasana'),
						'default' => '#e883ae',
						'validate' => 'color',
					),
					array(
						'id' => 'accent-color',
						'type' => 'color',
						'title' => esc_html__('Accent Color 1', 'jogasana'),
						'default' => '#754b75',
						'validate' => 'color',
					),
					array(
						'id' => 'accent-color2',
						'type' => 'color',
						'title' => esc_html__('Accent Color 2', 'jogasana'),
						'default' => '#334d5c',
						'validate' => 'color',
					),
					array(
						'id' => 'overlay-color',
						'type' => 'color_rgba',
						'title' => esc_html__('Overlay Color', 'jogasana'),
						'desc' => esc_html__('Color for portfolio hover overlay and other', 'jogasana'),
						'default'   => array(
							'color'     => '#334d5c',
							'alpha'     => .5
						),
					),
					array(
						'id' => 'selection-color',
						'type' => 'color',
						'desc' => esc_html__('The ::selection selector matches the portion of an element that is selected by a user.', 'jogasana'),
						'title' => esc_html__('Selection Background Color', 'jogasana'),
						'default'   => '#45b29d',
					),
					array(
						'id' => 'loading-color',
						'type' => 'color',
						'title' => esc_html__('Loading Color', 'jogasana'),
						'default' => '#e883ae',
						'validate' => 'color',
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Typography', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'select-google-charset',
						'type' => 'switch',
						'title' => esc_html__('Select Google Font Character Sets', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'google-charsets',
						'type' => 'button_set',
						'title' => esc_html__('Google Font Character Sets', 'jogasana'),
						'multi' => true,
						'required' => array('select-google-charset', 'equals', true),
						'options'=> array(
							'cyrillic' => 'Cyrrilic',
							'cyrillic-ext' => 'Cyrrilic Extended',
							'greek' => 'Greek',
							'greek-ext' => 'Greek Extended',
							'khmer' => 'Khmer',
							'latin' => 'Latin',
							'latin-ext' => 'Latin Extneded',
							'vietnamese' => 'Vietnamese'
						),
						'default' => array('latin','greek-ext','cyrillic','latin-ext','greek','cyrillic-ext','vietnamese','khmer')
					),
					array(
						'id' => 'body-font',
						'type' => 'typography',
						'title' => esc_html__('Body Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#777",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Poppins',
							'font-size' => '16px',
							'line-height' => '26px'
						),
					),
					array(
						'id' => 'h1-font',
						'type' => 'typography',
						'title' => esc_html__('H1 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '52px',
							'line-height' => '54px'
						),
					),
					array(
						'id' => 'h2-font',
						'type' => 'typography',
						'title' => esc_html__('H2 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '48px',
							'line-height' => '50px'
						),
					),
					array(
						'id' => 'h3-font',
						'type' => 'typography',
						'title' => esc_html__('H3 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '36px',
							'line-height' => '39px'
						),
					),
					array(
						'id'=>'h4-font',
						'type' => 'typography',
						'title' => esc_html__('H4 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '30px',
							'line-height' => '40px'
						),
					),
					array(
						'id' => 'h5-font',
						'type' => 'typography',
						'title' => esc_html__('H5 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '24px',
							'line-height' => '30px'
						),
					),
					array(
						'id' => 'h6-font',
						'type' => 'typography',
						'title' => esc_html__('H6 Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#333",
							'google' => true,
							'font-weight' => '400',
							'font-family' => 'Prata',
							'font-size' => '18px',
							'line-height' => '26px'
						),
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Backgrounds', 'jogasana'),
				'fields' => array(
					array(
						'id' => '102',
						'type' => 'info',
						'title' => esc_html__('Body Background', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'body-bg',
						'type' => 'background',
						'title' => esc_html__('Background', 'jogasana')
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Main Menu', 'jogasana'),
				'fields' => array(
					array(
						'id' => '103',
						'type' => 'info',
						'title' => esc_html__('Sticky Menu', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'sticky-menu-bg-color',
						'type' => 'color',
						'title' => esc_html__('Background Color', 'jogasana'),
						'default' => '#fff',
						'validate' => 'color',
					),
					array(
						'id' => '104',
						'type' => 'info',
						'title' => esc_html__( 'Top Level Menu Item', 'jogasana' ),
						'notice' => false
					),
					array(
						'id' => 'menu-font',
						'type' => 'typography',
						'title' => esc_html__('Menu Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'color' => false,
						'default'=> array(
							'google' => true,
							'font-weight' => '400',
							'font-family'=> 'Poppins',
							'font-size' => '16px',
							'line-height' => '26px'
						),
					),
					array(
						'id' => '105',
						'type' => 'info',
						'title' => esc_html__('If menu type is like 1,2,4,5', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'primary-toplevel-hover-color',
						'type' => 'link_color',
						'active' => false,
						'title' => esc_html__('Link Color', 'jogasana'),
						'default' => array(
							'regular' => '#333',
							'hover' => '#333'
						)
					),
					array(
						'id' => '106',
						'type' => 'info',
						'title' => esc_html__('If menu type is like 3', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'primary-toplevel-type3-link-color',
						'type' => 'link_color',
						'active' => false,
						'title' => esc_html__('Link Color', 'jogasana'),
						'default' => array(
							'regular' => '#fff',
							'hover' => '#fff'
						)
					),
					array(
						'id' => 'primary-toplevel-bg-color3',
						'type' => 'color',
						'title' => esc_html__('Background Color', 'jogasana'),
						'default' => '#754b75',
						'validate' => 'color',
					),
					array(
						'id'=>'107',
						'type' => 'info',
						'title' => esc_html__('Sub Menu', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'sub-menu-font',
						'type' => 'typography',
						'title' => esc_html__('Sub Menu Font', 'jogasana'),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'color' => false,
						'default'=> array(
							'google' => true,
							'font-weight' => '3200',
							'font-family'=> 'Poppins',
							'font-size' => '14px',
							'line-height' => '26px'
						),
					),
					array(
						'id' => 'sub-menu-bg-color',
						'type' => 'color',
						'title' => esc_html__('Background Color', 'jogasana'),
						'default' => '#293e4a',
						'validate' => 'color',
					),
					array(
						'id' => 'sub-menu-text-color',
						'type' => 'link_color',
						'active' => false,
						'title' => esc_html__('Link Color', 'jogasana'),
						'default' => array(
							'regular' => '#fff',
							'hover' => '#fff',
						)
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Header', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'header-bg',
						'type' => 'background',
						'title' => esc_html__('Background', 'jogasana'),
						'default' => array(
							'background-color' => '#fff',
							'background-image' => ''
						)
					),
				)
			);
			
			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Footer', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'footer-bg',
						'type' => 'background',
						'title' => esc_html__('Background for Type 1', 'jogasana'),
						'default' => array(
							'background-color' => '#2e4553',
							'background-image' => ''
						)
					),
					array(
						'id' => 'footer-bg2',
						'type' => 'background',
						'title' => esc_html__('Background for Type 2', 'jogasana'),
						'default' => array(
							'background-color' => '#2e4553'
						)
					),
					array(
						'id' => 'footer-bg3',
						'type' => 'background',
						'title' => esc_html__('Background for Type 3', 'jogasana'),
						'default' => array(
							'background-color' => '#2e4553',
							'background-image' => ''
						)
					),
					array(
						'id' => 'footer-bg4',
						'type' => 'background',
						'title' => esc_html__('Background for Type 4', 'jogasana'),
						'default' => array(
							'background-color' => '#2e4553',
							'background-image' => ''
						)
					),
					array(
						'id' => 'footer-heading-color',
						'type' => 'color',
						'title' => esc_html__('Heading Color', 'jogasana'),
						'default' => '#fff',
						'validate' => 'color',
					),
					array(
						'id' => 'footer-text-color',
						'type' => 'color',
						'title' => esc_html__('Text Color', 'jogasana'),
						'default' => '#f1f1f1',
						'validate' => 'color',
					),
					array(
						'id' => 'footer-link-color',
						'type' => 'link_color',
						'active' => false,
						'title' => esc_html__('Link Color', 'jogasana'),
						'default' => array(
							'regular' => '#45b29d',
							'hover' => '#45b29d',
						)
					),
					array(
						'id'=>'108',
						'type' => 'info',
						'title' => esc_html__('Footer Bottom', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'footer-bottom-link-color',
						'type' => 'link_color',
						'active' => false,
						'title' => esc_html__('Link Color', 'jogasana'),
						'default' => array(
							'regular' => '#fff',
							'hover' => '#fff',
						)
					),
					array(
						'id' => 'footer-bottom-text-color',
						'type' => 'color',
						'title' => esc_html__('Text Color', 'jogasana'),
						'default' => '#b4b7b9',
						'validate' => 'color',
					),
				)
			);

			// Header Settings
			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Header', 'jogasana'),
				'fields' => array(
				    array(
						'id' => 'header-sticky',
						'type' => 'switch',
						'title' => esc_html__('Header Sticky', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => '109',
						'type' => 'info',
						'title' => esc_html__('If header type is like 1', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => "header-button-url1",
						'type' => 'text',
						'title' => esc_html__('Button URL', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "header-button-title1",
						'type' => 'text',
						'title' => esc_html__('Button title', 'jogasana'),
						'default' => esc_html__('Book Now', 'jogasana')
					),
					array(
						'id' => 'header-type-1-button',
						'type' => 'switch',
						'title' => esc_html__('Show Button', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-1-search',
						'type' => 'switch',
						'title' => esc_html__('Show Search', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-1-login',
						'type' => 'switch',
						'title' => esc_html__('Show Login', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => '110',
						'type' => 'info',
						'title' => esc_html__('If header type is like 2', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'header-type-2-social',
						'type' => 'switch',
						'title' => esc_html__('Show Social', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-2-sidebar',
						'type' => 'switch',
						'title' => esc_html__('Show Top Sidebar', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => '111',
						'type' => 'info',
						'title' => esc_html__('If header type is like 3', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'header-type-3-login',
						'type' => 'switch',
						'title' => esc_html__('Show Login', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-3-search',
						'type' => 'switch',
						'title' => esc_html__('Show Search', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),	
					array(
						'id' => 'header-type-3-button',
						'type' => 'switch',
						'title' => esc_html__('Show Button', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => "header-button-url3",
						'type' => 'text',
						'title' => esc_html__('Button URL', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "header-button-title3",
						'type' => 'text',
						'title' => esc_html__('Button title', 'jogasana'),
						'default' => esc_html__('Join Free', 'jogasana')
					),
					array(
						'id' => '112',
						'type' => 'info',
						'title' => esc_html__('If header type is like 4', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => 'header-type-4-search',
						'type' => 'switch',
						'title' => esc_html__('Show Search', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-4-top-bar',
						'type' => 'switch',
						'title' => esc_html__('Show Top Bar', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),	
					array(
						'id' => '113',
						'type' => 'info',
						'title' => esc_html__('If header type is like 5', 'jogasana'),
						'notice' => false
					),	
					array(
						'id' => 'header-type-5-top-bar',
						'type' => 'switch',
						'title' => esc_html__('Show Top Bar', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),	
					array(
						'id' => '114',
						'type' => 'info',
						'title' => esc_html__('If header type is like 6', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => "header-button-url6",
						'type' => 'text',
						'title' => esc_html__('Button URL', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "header-button-title6",
						'type' => 'text',
						'title' => esc_html__('Button title', 'jogasana'),
						'default' => esc_html__('Book Now', 'jogasana')
					),
					array(
						'id' => 'header-type-6-button',
						'type' => 'switch',
						'title' => esc_html__('Show Button', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-6-search',
						'type' => 'switch',
						'title' => esc_html__('Show Search', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'header-type-6-login',
						'type' => 'switch',
						'title' => esc_html__('Show Login', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'align-menu',
						'type' => 'button_set',
						'title' => esc_html__('Menu Align( for Header1, Header6 )', 'jogasana'),
						'options' => array(
							'center' => esc_html__('center', 'jogasana'),
							'left' => esc_html__('left', 'jogasana'),
							'between' => esc_html__('between', 'jogasana')
						),
						'default' => 'between'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Top Bar', 'jogasana'),
				'fields' => array(
					array(
						'id' => "header-top-email",
						'type' => 'text',
						'title' => esc_html__('Top Email', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "header-top-phone",
						'type' => 'textarea',
						'title' => esc_html__('Top Phone', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => '115',
						'type' => 'info',
						'title' => esc_html__('Social Links', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => "header-social-linkedin",
						'type' => 'text',
						'title' => esc_html__('LinkedIn', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-tumblr",
						'type' => 'text',
						'title' => esc_html__('Tumblr', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-vimeo",
						'type' => 'text',
						'title' => esc_html__('Vimeo', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-youtube",
						'type' => 'text',
						'title' => esc_html__('Youtube', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-facebook",
						'type' => 'text',
						'title' => esc_html__('Facebook', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-twitter",
						'type' => 'text',
						'title' => esc_html__('Twitter', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-instagram",
						'type' => 'text',
						'title' => esc_html__('Instagram', 'jogasana'),
						'default' => '#'
					),
					array(
						'id' => "header-social-flickr",
						'type' => 'text',
						'title' => esc_html__('Flickr', 'jogasana'),
						'default' => '#'
					)
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Page Header Type', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'header-type',
						'type' => 'image_select',
						'full_width' => true,
						'title' => esc_html__('Header Type', 'jogasana'),
						'options' => $header_type,
						'default' => 'ys-type-4'
					),
				)
			);

			// Breadcrumbs
			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Breadcrumbs', 'jogasana'),
				'fields' => array(

				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Pages & Posts', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'show-pagetitle',
						'type' => 'switch',
						'title' => esc_html__('Show Block Page Title', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'align-breadcrumbs',
						'type' => 'select',
						'title' => esc_html__('Title Align', 'jogasana'),
						'options' => array(
							'center' => esc_html__('center', 'jogasana'),
							'left' => esc_html__('left', 'jogasana'),
							'right' => esc_html__('right', 'jogasana')
						),
						'default' => 'center' 
					),
					array(
						'id' => 'show-breadcrumbs',
						'type' => 'switch',
						'title' => esc_html__('Show Breadcrumbs', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'breadcrumbs-bg',
						'type' => 'background',
						'title' => esc_html__('Background', 'jogasana'),
						'default' => array(
							'background-color' => '#f9f9f9',
							'background-image' => ''
						)
					),
				)
			);

		if ( class_exists( 'WooCommerce' ) ) {
			
			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Shop', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'shop-show-pagetitle',
						'type' => 'switch',
						'title' => esc_html__('Show Page Title', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'shop-align-breadcrumbs',
						'type' => 'select',
						'title' => esc_html__('Title Align', 'jogasana'),
						'options' => array(
							'center' => esc_html__('center', 'jogasana'),
							'left' => esc_html__('left', 'jogasana'),
							'right' => esc_html__('right', 'jogasana')
						),
						'default' => 'left' 
					),
					array(
						'id' => 'shop-show-breadcrumbs',
						'type' => 'switch',
						'title' => esc_html__('Show Breadcrumbs', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'shop-breadcrumbs-bg',
						'type' => 'background',
						'title' => esc_html__('Background', 'jogasana'),
						'default' => array(
							'background-color' => '#f9f9f9',
							'background-image' => ''
						)
					),
				)
			);
		}		
			
		// Events
		if ( class_exists( 'Tribe__Events__Main' ) ) {
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Events', 'jogasana'),
				'fields' => array(
				array(
						'id' => 'events-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				array(
						'id' => "events-title",
						'type' => 'text',
						'title' => esc_html__('Enter Page Event Title', 'jogasana'),
						'default' => esc_html__('Upcoming Events', 'jogasana')
					),	
				)
			);
		}
			
		if ( class_exists( 'WooCommerce' ) ) {

				// Shop
				$this->sections[] = array(
					'icon' => 'el-icon-shopping-cart',
					'icon_class' => 'icon',
					'title' => esc_html__('Shop', 'jogasana'),
					'fields' => array(
						array(
							'id' => '116',
							'type' => 'info',
							'title' => esc_html__('Label Status', 'jogasana'),
							'notice' => false
						),
						array(
							'id' => 'product-stock',
							'type' => 'switch',
							'title' => esc_html__('Show "Out of stock" Status', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-featured',
							'type' => 'switch',
							'title' => esc_html__('Show "Featured" Status', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-sale',
							'type' => 'switch',
							'title' => esc_html__('Show "Sale" Status', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
					)
				);
				
				$this->sections[] = array(
					'icon_class' => 'icon',
					'subsection' => true,
					'title' => esc_html__('Product Archives', 'jogasana'),
					'fields' => array(
						array(
							'id' => 'product-archive-layout',
							'type' => 'image_select',
							'title' => esc_html__('Page Layout', 'jogasana'),
							'options' => $page_layouts,
							'default' => 'cp-right-sidebar'
						),
						array(
							'id' => 'product-sidebar',
							'type' => 'select',
							'title' => esc_html__('Select Sidebar', 'jogasana'),
							'required' => array('product-archive-layout', 'equals', $sidebars),
							'data' => 'sidebars',
							'default' => 'shop-widget-area'
						),
						array(
							'id' => 'shop-archive-footer-sidebar',
							'type' => 'select',
							'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
							'data' => 'page',
							'default' => ''
						),
						array(
							'id' => 'shop-count-item',
							'type' => 'text',
							'title' => esc_html__('Products per Page', 'jogasana'),
							'desc' => esc_html__('Product counts.', 'jogasana'),
							'default' => '12'
						),
						array(
							'id' => 'shop-product-cols',
							'type' => 'button_set',
							'title' => esc_html__('Shop Page Product Columns', 'jogasana'),
							'options' => jogasana_product_columns(),
							'default' => '3',
						),
					)
				);
				
				$this->sections[] = array(
					'icon_class' => 'icon',
					'subsection' => true,
					'title' => esc_html__('Single Product', 'jogasana'),
					'fields' => array(
						array(
							'id' => 'product-single-layout',
							'type' => 'image_select',
							'title' => esc_html__('Single Layout', 'jogasana'),
							'options' => $page_layouts,
							'default' => 'cp-right-sidebar'
						),
						array(
							'id' => 'product-single-sidebar',
							'type' => 'select',
							'title' => esc_html__('Select Sidebar', 'jogasana'),
							'required' => array('product-single-layout', 'equals', $sidebars),
							'data' => 'sidebars',
							'default' => 'shop-widget-area'
						),
						array(
							'id' => 'shop-single-footer-sidebar',
							'type' => 'select',
							'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
							'data' => 'page',
							'default' => ''
						),
						array(
							'id' => 'product-short-description',
							'type' => 'switch',
							'title' => esc_html__('Show Short Description', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-metas',
							'type' => 'button_set',
							'title' => esc_html__('Product Meta', 'jogasana'),
							'multi' => true,
							'options' => array(
								'tags' => esc_html__('Tags', 'jogasana'),
								'cats' => esc_html__('Categories', 'jogasana'),
								'-' => esc_html__('None', 'jogasana'),
							),
							'default' => array('tags', '-')
						),
						array(
							'id' => 'product-related',
							'type' => 'switch',
							'title' => esc_html__('Show Related Products', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-related-count',
							'type' => 'text',
							'required' => array('product-related', 'equals', true),
							'title' => esc_html__('Related Count items', 'jogasana'),
							'default' => '3'
						),
						array(
							'id' => 'product-upsells',
							'type' => 'switch',
							'title' => esc_html__('Show Up-Sells', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-upsells-count',
							'type' => 'text',
							'required' => array('product-upsells', 'equals', true),
							'title' => esc_html__('Up-Sells Columns', 'jogasana'),
							'default' => '3'
						),
						array(
							'id' => '117',
							'type' => 'info',
							'title' => esc_html__('Social Links', 'jogasana'),
							'notice' => false
						),
						array(
							'id' => 'product-single-share',
							'type' => 'switch',
							'title' => esc_html__('Show Social Links', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
					)
				);
				
				$this->sections[] = array(
					'icon_class' => 'icon',
					'subsection' => true,
					'title' => esc_html__('Cart', 'jogasana'),
					'fields' => array(
						array(
							'id' => 'product-crossell',
							'type' => 'switch',
							'title' => esc_html__('Show Cross-Sells', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => 'product-crossell-count',
							'type' => 'text',
							'required' => array('product-crossell', 'equals', true),
							'title' => esc_html__('Cross Sells Columns', 'jogasana'),
							'default' => '2'
						),
					)
				);
				
		}		
			
			// Place
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Place', 'jogasana'),
				'fields' => array(
				array(
						'id' => 'place-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				)
			);
			
			
			// Team
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Team Members', 'jogasana'),
				'fields' => array(
				array(
						'id' => 'team-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				)
			);
			
			// Testimonials
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Testimonials', 'jogasana'),
				'fields' => array(
				array(
						'id' => 'testimonials-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				)
			);
			
			// Classes
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Classes', 'jogasana'),
				'fields' => array(
				array(
						'id' => 'classes-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				array(
						'id' => 'single-classes-date',
						'type' => 'switch',
						'title' => esc_html__('Show date on single', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
				array(
						'id' => 'single-classes-cat',
						'type' => 'switch',
						'title' => esc_html__('Show categories on single', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),	
				array(
						'id' => 'single-classes-author',
						'type' => 'switch',
						'title' => esc_html__('Show author on single', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),	
				array(
						'id' => 'single-classes-time',
						'type' => 'switch',
						'title' => esc_html__('Show time on single', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),		
				array(
						'id' => 'single-classes-level',
						'type' => 'switch',
						'title' => esc_html__('Show level on single', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),		
					
				)
			);
			
			if ( class_exists( 'Jogasana_Portfolio_Config' ) ) {
			
				// Portfolio
				$this->sections[] = array(
					'icon' => 'el-icon-gallery',
					'icon_class' => 'icon',
					'title' => esc_html__('Portfolio', 'jogasana'),
					'fields' => array(
						array(
							'id' => 'portfolio-related',
							'type' => 'switch',
							'title' => esc_html__('Show "Related" on single portfolio', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
							'id' => "portfolio-link",
							'type' => 'text',
							'title' => esc_html__('Link to portfolio', 'jogasana'),
							'default' => ''
						),
						array(
							'id' => 'portfolio-single-share',
							'type' => 'switch',
							'title' => esc_html__('Show Social Links', 'jogasana'),
							'default' => false,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
						'id' => 'portfolio-share-facebook',
						'type' => 'switch',
						'title' => esc_html__('Enable Facebook Share', 'jogasana'),
						'required' => array('portfolio-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'portfolio-share-twitter',
						'type' => 'switch',
						'title' => esc_html__('Enable Twitter Share', 'jogasana'),
						'required' => array('portfolio-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'portfolio-share-pinterest',
						'type' => 'switch',
						'title' => esc_html__('Enable Pinterest Share', 'jogasana'),
						'required' => array('portfolio-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'portfolio-share-email',
						'type' => 'switch',
						'title' => esc_html__('Enable Email Share', 'jogasana'),
						'required' => array('portfolio-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
						array(
							'id' => 'portfolio-nav',
							'type' => 'switch',
							'title' => esc_html__('Prev/Next Navigation', 'jogasana'),
							'default' => true,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
					)
				);
			
			}

			// Blog
			$this->sections[] = array(
				'icon' => 'el-icon-file',
				'icon_class' => 'icon',
				'title' => esc_html__('Blog', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'post-metas',
						'type' => 'button_set',
						'title' => esc_html__('Post Meta', 'jogasana'),
						'multi' => true,
						'options'=> array(
							'author' => esc_html__('Author', 'jogasana'),
							'date' => esc_html__('Date', 'jogasana'),
							'cats' => esc_html__('Categories', 'jogasana'),
							'comments' => esc_html__('Comments', 'jogasana'),
							'-' => esc_html__('None', 'jogasana')
						),
						'default' => array( 'author','date','-' )
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Blog Post', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'excerpt-count-big-thumbs',
						'type' => 'text',
						'title' => esc_html__( 'Excerpt Length', 'jogasana' ),
						'desc' => esc_html__( 'The number of words for style Count Big Thumbs ', 'jogasana' ),
						'default' => '300'
					),
					array(
						'id' => 'excerpt-count-small-thumbs',
						'type' => 'text',
						'title' => esc_html__( 'Excerpt Length', 'jogasana' ),
						'desc' => esc_html__( 'The number of words for style Count Small Thumbs ', 'jogasana' ),
						'default' => '300'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Post Archive', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'post-archive-layout',
						'type' => 'image_select',
						'title' => esc_html__('Page Layout', 'jogasana'),
						'options' => $page_layouts,
						'default' => 'ys-no-sidebar'
					),
					array(
						'id' => 'archive-post-sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'jogasana'),
						'required' => array( 'post-archive-layout','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'general-widget-area'
					),
					array(
						'id' => 'archive-post-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Single Post', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'post-single-layout',
						'type' => 'image_select',
						'title' => esc_html__('Page Layout', 'jogasana'),
						'options' => $page_layouts,
						'default' => 'ys-right-sidebar'
					),
					array(
						'id' => 'single-post-sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'jogasana'),
						'required' => array( 'post-single-layout','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'general-widget-area'
					),
					array(
						'id' => 'single-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
					array(
						'id' => 'post-title',
						'type' => 'switch',
						'title' => esc_html__('Show Title', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'single-post-metas',
						'type' => 'button_set',
						'title' => esc_html__('Post Meta', 'jogasana'),
						'multi' => true,
						'options'=> array(
							'cats' => esc_html__('Categories', 'jogasana'),
							'author' => esc_html__('Author', 'jogasana'),
							'date' => esc_html__('Date', 'jogasana'),
							'comments' => esc_html__('Comments', 'jogasana'),
							'-' => esc_html__('None', 'jogasana')
						),
						'desc' => esc_html__('Located at the top of the post', 'jogasana'),
						'default' => array( 'author','date','comments', '-' )
					),
					array(
						'id' => 'post-tag',
						'type' => 'switch',
						'title' => esc_html__('Show Tags', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'post-single-share',
						'type' => 'switch',
						'title' => esc_html__('Show Social Links', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'post-nav',
						'type' => 'switch',
						'title' => esc_html__('Prev/Next Navigation', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'post-related',
						'type' => 'switch',
						'title' => esc_html__('Related', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'post-author',
						'type' => 'switch',
						'title' => esc_html__('Show Author Info Box', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'post-comments',
						'type' => 'switch',
						'title' => esc_html__('Show Comments', 'jogasana'),
						'default' => true,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
				)
			);

			// Javascript Code
			$this->sections[] = array(
				'icon_class' => 'el-icon-edit',
				'title' => esc_html__('Javascript Code', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'js-code-head',
						'type' => 'ace_editor',
						'title' => esc_html__('Javascript Code Before &lt;/head&gt;', 'jogasana'),
						'subtitle' => esc_html__('Paste your JS code here.', 'jogasana'),
						'mode' => 'javascript',
						'theme' => 'monokai',
						'default' => ""
					)
				)
			);

			// Footer Settings
			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Footer', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'footer-type',
						'type' => 'button_set',
						'title' => esc_html__('Footer Type', 'jogasana'),
						'options' => array(
							'footer-1' => esc_html__('Type 1', 'jogasana'),
							'footer-2' => esc_html__('Type 2', 'jogasana'),
							'footer-3' => esc_html__('Type 3', 'jogasana'),
							'footer-4' => esc_html__('Type 4', 'jogasana')
						),
						'default' => 'footer-1'
					),
					array(
						'id' => "footer-copyright",
						'type' => 'textarea',
						'title' => esc_html__('Copyright', 'jogasana'),
						'default' => sprintf( wp_kses(__('Copyright &copy; %s Jogasana. All Rights Reserved.Privacy Policy | Terms & Conditions', 'jogasana'), 'default'), date('Y') )
					),
					array(
						'id' => 'footer-pay-box',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Pay box', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/cards.jpg')
						)
					),
					array(
						'id' => 'footer-logo',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Footer Logo(for type 1)', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo.png')
						)
					),
					array(
						'id' => 'footer_logo_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Footer Logo HiDPI(for type 1)', 'jogasana'),
						'default' => array(
							'url' => get_theme_file_uri('images/logo@2x.png')
						)
					),
					array(
						'id' => 'show-footer-menu',
						'type' => 'switch',
						'title' => esc_html__('Show Footer Menu(for type 1,2)', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'show-footer-newsletter',
						'type' => 'switch',
						'title' => esc_html__('Show Footer Newsletter(for type 4)', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'show-footer-row-top',
						'type' => 'switch',
						'title' => esc_html__('Show Row Top widgets ?', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => 'show-footer-row-middle',
						'type' => 'switch',
						'title' => esc_html__('Show Row Middle widgets ?', 'jogasana'),
						'default' => false,
						'on' => esc_html__('Yes', 'jogasana'),
						'off' => esc_html__('No', 'jogasana'),
					),
					array(
						'id' => '118',
						'type' => 'info',
						'title' => esc_html__('Footer Social Links', 'jogasana'),
						'notice' => false
					),
					array(
						'id' => "footer-social-linkedin",
						'type' => 'text',
						'title' => esc_html__('LinkedIn', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-tumblr",
						'type' => 'text',
						'title' => esc_html__('Tumblr', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-vimeo",
						'type' => 'text',
						'title' => esc_html__('Vimeo', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-youtube",
						'type' => 'text',
						'title' => esc_html__('Youtube', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-facebook",
						'type' => 'text',
						'title' => esc_html__('Facebook', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-twitter",
						'type' => 'text',
						'title' => esc_html__('Twitter', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-instagram",
						'type' => 'text',
						'title' => esc_html__('Instagram', 'jogasana'),
						'default' => ''
					),
					array(
						'id' => "footer-social-flickr",
						'type' => 'text',
						'title' => esc_html__('Flickr', 'jogasana'),
						'default' => ''
					),
				)
			);

			// 404 Page
			$this->sections[] = array(
				'icon' => 'el-icon-error',
				'icon_class' => 'icon',
				'title' => esc_html__('404 Page', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'error-content',
						'type' => 'textarea',
						'title' => esc_html__('Error text', 'jogasana'),
						'validate' => 'html_custom',
						'default' => "It's probably some thing we've done wrong but now we know about it and <br> we'll try to fix it. Go Home or try to search:",
						'allowed_html' => array(
							'a' => array(
								'href' => array(),
								'title' => array()
							),
							'br' => array(),
							'em' => array(),
							'strong' => array()
						)
					),
					array(
						'id' => '404-footer-sidebar',
						'type' => 'select',
						'title' => esc_html__('Get widgets for footer from page', 'jogasana'),
						'data' => 'page',
						'default' => ''
					),
				)
			);

			// coming-soon
			$this->sections[] = array(
				'icon' => 'el-icon-error',
				'icon_class' => 'icon',
				'title' => esc_html__('Coming-soon Page', 'jogasana'),
				'fields' => array(
					array(
						'id' => 'coming-soon-copyright',
						'type' => 'textarea',
						'title' => esc_html__('Copyright text', 'jogasana'),
						'validate' => 'html_custom',
						'default' => "<p>Copyright Jogasana © 2018. All Rights Reserved.</p>",
					),
					array(
							'id' => 'coming-soon-social',
							'type' => 'switch',
							'title' => esc_html__('Show Social Links', 'jogasana'),
							'default' => false,
							'on' => esc_html__('Yes', 'jogasana'),
							'off' => esc_html__('No', 'jogasana'),
						),
						array(
						'id' => "coming-soon-social-linkedin",
						'type' => 'text',
						'title' => esc_html__('LinkedIn', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-tumblr",
						'type' => 'text',
						'title' => esc_html__('Tumblr', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-vimeo",
						'type' => 'text',
						'title' => esc_html__('Vimeo', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-youtube",
						'type' => 'text',
						'title' => esc_html__('Youtube', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-facebook",
						'type' => 'text',
						'title' => esc_html__('Facebook', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-twitter",
						'type' => 'text',
						'title' => esc_html__('Twitter', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-instagram",
						'type' => 'text',
						'title' => esc_html__('Instagram', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
					array(
						'id' => "coming-soon-social-flickr",
						'type' => 'text',
						'title' => esc_html__('Flickr', 'jogasana'),
						'required' => array('coming-soon-social','equals',true),
						'default' => '#'
					),
				)
			);

		}

		public function setArguments() {

			$theme = $this->theme;

			$this->args = array(
				'opt_name'          => 'jogasana_settings',
				'display_name'      => $theme->get('Name') . ' ' . esc_html__('Theme Options', 'jogasana'),
				'display_version'   => esc_html__('Theme Version: ', 'jogasana') . strtolower($theme->get('Version')),
				'menu_type'         => 'submenu',
				'allow_sub_menu'    => true,
				'menu_title'        => esc_html__('Theme Options', 'jogasana'),
				'page_title'        => esc_html__('Theme Options', 'jogasana'),
				'footer_credit'     => esc_html__('Theme Options', 'jogasana'),

				'google_api_key' => 'AIzaSyBQft4vTUGW75YPU6c0xOMwLKhxCEJDPwg',
				'disable_google_fonts_link' => true,

				'async_typography'  => false,
				'admin_bar'         => false,
				'admin_bar_icon'       => 'dashicons-admin-generic',
				'admin_bar_priority'   => 50,
				'global_variable'   => '',
				'dev_mode'          => false,
				'customizer'        => false,
				'compiler'          => false,

				'page_priority'     => null,
				'page_parent'       => 'themes.php',
				'page_permissions'  => 'manage_options',
				'menu_icon'         => '',
				'last_tab'          => '',
				'page_icon'         => 'icon-themes',
				'page_slug'         => 'jogasana_settings',
				'save_defaults'     => true,
				'default_show'      => false,
				'default_mark'      => '',
				'show_import_export' => true,
				'show_options_object' => false,

				'transient_time'    => 60 * MINUTE_IN_SECONDS,
				'output'            => false,
				'output_tag'        => false,

				'database'              => '',
				'system_info'           => false,

				'hints' => array(
					'icon'          => 'icon-question-sign',
					'icon_position' => 'right',
					'icon_color'    => 'lightgray',
					'icon_size'     => 'normal',
					'tip_style'     => array(
						'color'         => 'light',
						'shadow'        => true,
						'rounded'       => false,
						'style'         => '',
					),
					'tip_position'  => array(
						'my' => 'top left',
						'at' => 'bottom right',
					),
					'tip_effect'    => array(
						'show'          => array(
							'effect'        => 'slide',
							'duration'      => '500',
							'event'         => 'mouseover',
						),
						'hide'      => array(
							'effect'    => 'slide',
							'duration'  => '500',
							'event'     => 'click mouseleave',
						),
					),
				),
				'ajax_save'                 => false,
				'use_cdn'                   => true,
			);

		}

	}

	global $jogasana_redux_settings;
	$jogasana_redux_settings = new jogasana_redux_settings();

}