<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Jogasana for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */

require_once get_template_directory() . '/admin/class-tgm-plugin-activation.php';

add_action( 'tgmpa_register', 'jogasana_register_required_plugins' );

if (!function_exists('jogasana_added_admin_action')) {

	function jogasana_added_admin_action() {
		add_action( 'admin_enqueue_scripts', 'jogasana_added_plugin_style' );
	}

	function jogasana_added_plugin_style() {
		wp_enqueue_style( 'jogasana_admin_plugins', get_theme_file_uri('css/admin-plugin.css'), array() );
	}

	add_action( 'load-plugins.php', 'jogasana_added_admin_action', 1 );

}
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function jogasana_register_required_plugins() {

	// disable visual composer automatic update
	global $vc_manager;
	if ( $vc_manager ) {

		$vc_updater = $vc_manager->updater();

		if ( $vc_updater ) {
			remove_action('wp_ajax_nopriv_vc_check_license_key', array(&$vc_updater, 'checkLicenseKeyFromRemote'));
		}
	}

	$is_plugins_page = false;
	if ( ( isset( $_GET['page'] ) && 'jogasana-plugins' === $_GET['page'] ) ||
		( isset( $_GET['page'] ) && 'install-required-plugins' === $_GET['page'] ) 
	) {
		$is_plugins_page = true;
	}

	$bundled_plugins = Jogasana()->get_bundled_plugins();

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		array(
			'name'     => esc_html__('Redux Framework', 'jogasana'),
			'slug'     => 'redux-framework',
			'required' => true
		),
		
		array(
			'name'     => esc_html__('WooCommerce', 'jogasana'),
			'slug'     => 'woocommerce',
			'required' => false
		),

		array(
			'name'     => esc_html__('Contact Form 7', 'jogasana'),
			'slug'     => 'contact-form-7',
			'required' => false
		),

		array(
			'name' => esc_html__('Latest Tweets Widget', 'jogasana'),
			'slug' => 'latest-tweets-widget',
			'required' => false
		),
		
		array(
            'name'               => esc_html__('The Events Calendar', 'jogasana'), 
            'slug'               => 'the-events-calendar', 
            'required'           => false
        ),
		
		array(
            'name'               => esc_html__('Timetable and Event Schedule by MotoPress', 'jogasana'), 
            'slug'               => 'mp-timetable', 
            'required'           => false
        ),
		
		array(
			'name'      		 => esc_html__('Login With Ajax', 'jogasana'),
			'slug'      		 => 'login-with-ajax',
			'required'  		 => false
		),
		
		array(
			'name'      		 => esc_html__('Smash Balloon Instagram Feed', 'jogasana'),
			'slug'      		 => 'instagram-feed',
			'required'  		 => false
		),
		
		array(
			'name'      		 => esc_html__('GiveWP – Donation Plugin and Fundraising Platform', 'jogasana'),
			'slug'      		 => 'give',
			'required'  		 => false
		),

		// This is an example of how to include a plugin from the WordPress Plugin Repository.

		array(
			'name'               => 'Revolution Slider',
			'slug'               => 'revslider',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/jogasana/pluginus24/revslider.zip',
			'required'           => false,
			'version'            => '6.5.5',
			'force_activation'   => false,
			'force_deactivation' => false
		),
		array(
			'name'               => 'Mega Main Menu',
			'slug'               => 'mega_main_menu',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/mega_main_menu.zip',
			'required'           => false,
			'version'            => '',
			'force_activation'   => false,
			'force_deactivation' => false
		),
		array(
			'name'               => 'Jogasana Theme Functionality',
			'slug'               => 'jogasana-theme-functionality',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/jogasana/pluginus24/jogasana-theme-functionality.zip',
			'required'           => true,
			'version'            => '1.5',
			'force_activation'   => false,
			'force_deactivation' => false
		),

		array(
			'name'               => 'Easy Tables',
			'slug'               => 'easy-tables-vc',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/easy-tables-vc.zip',
			'required'           => false,
			'version'            => '',
			'force_activation'   => false,
			'force_deactivation' => false
		),

		array(
			'name'               => 'WPBakery Visual Composer',
			'slug'               => 'js_composer',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/js_composer.zip',
			'required'           => false,
			'version'            => '6.7.0',
			'force_activation'   => false,
			'force_deactivation' => false
		),
		
		array(
			'name'               => 'Ultimate Addons for Visual Composer',
			'slug'               => 'Ultimate_VC_Addons',
			'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/Ultimate_VC_Addons.zip',
			'required'           => false,
			'version'            => '3.19.11',
			'force_activation'   => false,
			'force_deactivation' => false
		),
		
		array(
            'name'               => 'Envato Market', 
            'slug'               => 'envato-market', 
            'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/envato-market.zip',
            'required'           => false, 
            'version'            => '2.0.6', 
            'force_activation'   => false, 
            'force_deactivation' => false
        ),
		
		 array(
            'name'               => 'Indeed Smart PopUp', 
            'slug'               => 'indeed-smart-popup', 
            'source'             => 'http://velikorodnov.com/wordpress/sample-data/jogasana/pluginus24/indeed-smart-popup.zip',
            'required'           => false, 
            'version'            => '', 
            'force_activation'   => false, 
            'force_deactivation' => false
        ),
		/*
		array(
            'name'               => 'SUMO Subscriptions', 
            'slug'               => 'sumosubscriptions', 
            'source'             => 'http://velikorodnov.com/wordpress/sample-data/jogasana/pluginus24/sumosubscriptions.zip',
            'required'           => false, 
            'version'            => '', 
            'force_activation'   => false, 
            'force_deactivation' => false
        ),
		
		array(
            'name'               => 'SUMO Memberships', 
            'slug'               => 'sumomemberships', 
            'source'             => 'http://velikorodnov.com/wordpress/sample-data/jogasana/pluginus24/sumomemberships.zip',
            'required'           => false, 
            'version'            => '', 
            'force_activation'   => false, 
            'force_deactivation' => false
        ),
		*/

	);

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'       => 'jogasana', 
		'id'           => 'jogasana',                 
		'default_path' => get_theme_file_path( 'admin/plugins/' ),                      
		'menu'         => 'install-required-plugins',
		'has_notices'  => true,                    
		'dismissable'  => true,                    
		'dismiss_msg'  => '',                     
		'is_automatic' => true,                 
		'message'      => ''
	);

	tgmpa( $plugins, $config );

}