<?php

class WPBakeryShortCode_VC_mad_place extends WPBakeryShortCode {

	public $atts = array();
	public $entries = '';

	protected function content($atts, $content = null) {

		$this->atts = shortcode_atts(array(
			'title' 	 => '',
			'subtitle' 	 => '',
			'tag_title'  => 'h2',
			'description' 	 => '',
			'title_color' => '',
			'description_color' => '',
			'title_align' => '',
			'description_align' => '',
			'layout' => 'type-1',
			'items' => -1,
			'columns' => 2,
			'categories' => array(),
			'orderby' => 'date',
			'order' => 'DESC',
			'paginate' => 'none',
			'align_pagination' => 'align-left',
			'css_animation' => ''
		), $atts, 'vc_mad_place');

		$this->query_entries();
		return $this->html();
	}

	public function query_entries() {
		$params = $this->atts;
		$page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' );
		if (!$page || $params['paginate'] == 'none') $page = 1;

		$tax_query = array();

		if ( !empty($params['categories']) ) {
			$categories = explode(',', $params['categories']);
			$tax_query = array(
				'relation' => 'AND',
				array(
					'taxonomy' => 'place_category',
					'field' => 'id',
					'terms' => $categories
				)
			);
		}

		$query = array(
			'post_type' => 'place',
			'post_status'  => 'publish',
			'orderby' => $params['orderby'],
			'order' => $params['order'],
			'paged' => $page,
			'posts_per_page' => $params['items'],
			'tax_query' 	 => $tax_query
		);

		$this->entries = new WP_Query($query);
	}

	public function html() {

		if ( empty($this->entries) || empty($this->entries->posts) ) return;

		$params = $this->atts;
		$wrapper_attributes = array();
		$layout = $items = $categories = $orderby = $order = $style = '';

		$title = $tag_title = $type = $columns = $filter = $pagination = '';
		$description = !empty($params['description']) ? $params['description'] : '';
		$title_color = !empty($params['title_color']) ? $params['title_color'] : '';
		$description_color = !empty($params['description_color']) ? $params['description_color'] : '';
		$css_animation = !empty($params['css_animation']) ? $params['css_animation'] : '';
		$title_align = !empty($params['title_align']) ? $params['title_align'] : '';
		$description_align = !empty($params['description_align']) ? $params['description_align'] : '';
		$paginate = !empty($atts['paginate']) ? $atts['paginate'] : 'pagination';
		$align_pagination = !empty($atts['align_pagination']) ? $atts['align_pagination'] : 'align-left';
		$columns = !empty($atts['columns']) ? $atts['columns'] : 2;

		extract($this->atts);

		$css_classes = array(
			'custom_place', 'wpb_content_element', 'paginate_'.$paginate
		);

		$css_class = preg_replace( '/\s+/', ' ', implode( ' ', array_filter( $css_classes ) ) );
		$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';

		if ( '' !== $css_animation ) {
			$wrapper_attributes[] = Jogasana_Helper::create_data_string_animation( $css_animation, 0, 0 );
		}
		$counter = 0;
		
		ob_start(); ?>

		<div <?php echo implode( ' ', $wrapper_attributes ) ?> >
        	
			<?php if ( $subtitle != '' ): ?>
        	<h5 class="section-sub-title <?php echo esc_attr($title_align) ?>" <?php echo sprintf('%s', $style) ?>><?php echo esc_html($subtitle) ?></h5>
            <?php endif; ?>

			<?php
			echo Jogasana_Vc_Config::getParamTitle(
				array(
					'title' => $title,
					'tag_title' => $tag_title,
					'description' => $description,
					'title_color' => $title_color,
					'align' => $title_align,
					'align_des' => $description_align,
					'description_color' => $description_color,
				)
			);
			
			?>

			<?php if ( $layout == 'type-1' ) { ?>
                
                <div class="challenges flex-row item-col-<?php echo esc_attr($columns) ?>">

					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$name = get_the_title($id);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$link  = get_permalink($id);
						?>
						
						<div class="item-col" >
                        	<div class="challenge-item">
                                <div class="bg-img" data-bg="<?php echo Jogasana_Helper::get_post_featured_image( $id, 'jogasana-post-big'); ?>" ></div>
                            	<a href="<?php echo esc_url($link) ?>" class="link"></a>
								<div class="inner">
                
									<h3 class="item-title"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name) ?></a></h3>
									<div class="our-info style-3">
									
									  <div class="info-item">
										<i class="licon-signal"></i>
										<div class="wrapper">
										<?php $cur_terms = wp_get_post_terms($id, 'place_category'); ?>
										<?php if ( !empty($cur_terms) ): ?>
										
										<?php 
										foreach( $cur_terms as $cur_term ){
											echo '<a href="'. get_term_link( (int)$cur_term->term_id, $cur_term->taxonomy ) .'">'. esc_html($cur_term->name) .'</a>,';
										}
										?>		
										<?php endif; ?>
										</div>
									  </div>
									
									</div>

								</div>
							
                            </div>
						</div>

					<?php endforeach; ?>
                    
                  </div>

			<?php } elseif ( $layout == 'type-2' ) { ?>

                <div class="challenges masonry flex-row item-col-2">

					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$name = get_the_title($id);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$link  = get_permalink($id);
						
						$counter++;
						?>
						
						<?php if ($counter === 1) { ?>
                        <div class="item-col full-size" >
                        	<div class="challenge-item">
                                <div class="bg-img" data-bg="<?php echo Jogasana_Helper::get_post_featured_image( $id, 'jogasana-post-big'); ?>" ></div>
                            	<a href="<?php echo esc_url($link) ?>" class="link"></a>
								<div class="inner">
                
									<h3 class="item-title"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name) ?></a></h3>
									<?php $cur_terms = wp_get_post_terms($id, 'place_category'); ?>
										<?php if ( !empty($cur_terms) ): ?>
										
										<?php 
										foreach( $cur_terms as $cur_term ){
											echo '<a class="item-country" href="'. get_term_link( (int)$cur_term->term_id, $cur_term->taxonomy ) .'">'. esc_html($cur_term->name) .'</a>';
										}
										?>		
										<?php endif; ?>

								</div>
                            </div>
						</div>
						
						<div class="item-col">
						
						<?php } elseif($counter === 2) { ?>
						
						<div class="flex-row item-col-1"><div class="item-col half-size">
						
							<div class="challenge-item">
                                <div class="bg-img" data-bg="<?php echo Jogasana_Helper::get_post_featured_image( $id, 'jogasana-gallery-grid'); ?>" ></div>
                            	<a href="<?php echo esc_url($link) ?>" class="link"></a>
								<div class="inner">
                
									<h3 class="item-title"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name) ?></a></h3>
									<?php $cur_terms = wp_get_post_terms($id, 'place_category'); ?>
										<?php if ( !empty($cur_terms) ): ?>
										
										<?php 
										foreach( $cur_terms as $cur_term ){
											echo '<a class="item-country" href="'. get_term_link( (int)$cur_term->term_id, $cur_term->taxonomy ) .'">'. esc_html($cur_term->name) .'</a>';
										}
										?>		
										<?php endif; ?>

								</div>
                            </div>
						
						</div></div>
						
						<?php } elseif($counter > 2) { ?>
						
						<?php if($counter === 3) { ?><div class="flex-row item-col-2"><?php } ?>
						<div class="item-col half-size">
						
							<div class="challenge-item">
                                <div class="bg-img" data-bg="<?php echo Jogasana_Helper::get_post_featured_image( $id, 'jogasana-masonry2'); ?>" ></div>
                            	<a href="<?php echo esc_url($link) ?>" class="link"></a>
								<div class="inner">
                
									<h3 class="item-title"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name) ?></a></h3>
									<?php $cur_terms = wp_get_post_terms($id, 'place_category'); ?>
										<?php if ( !empty($cur_terms) ): ?>
										
										<?php 
										foreach( $cur_terms as $cur_term ){
											echo '<a class="item-country" href="'. get_term_link( (int)$cur_term->term_id, $cur_term->taxonomy ) .'">'. esc_html($cur_term->name) .'</a>';
										}
										?>		
										<?php endif; ?>

								</div>
                            </div>
						
						</div>
						<?php }  ?>
							
					<?php endforeach; ?>
						<?php if($counter >= 3) { ?></div><?php } ?>
					
						</div>
					
                    
                  </div>
                  
				<?php } ?>
				
				<?php if ( $paginate == "pagination" && $jogasana_pagination = jogasana_pagination($this->entries) ) : ?>
				<div class="<?php echo esc_attr( $align_pagination ) ?>">
				<?php echo wp_kses_post($jogasana_pagination); ?>
				</div>
			<?php endif; ?>
				
		</div>	
		 
		 <?php wp_reset_postdata(); ?>

		<?php return ob_get_clean();
	}

}