<?php

class WPBakeryShortCode_VC_mad_testimonials extends WPBakeryShortCode {

	public $atts = array();
	public $entries = '';

	protected function content($atts, $content = null) {

		$this->atts = shortcode_atts(array(
			'subtitle' 	 => '',
			'title' 	 => '',
			'tag_title'  => 'h2',
			'description' 	 => '',
			'title_color' => '',
			'description_color' => '',
			'title_align' => '',
			'description_align' => '',
			'divider_color' => '',
			'author_color' => '',
			'divider' => '',
			'link' => '',
			'layout' => 'type-1',
			'items' => -1,
			'columns' => 3,
			'categories' => array(),
			'orderby' => 'date',
			'order' => 'DESC',
			'autoplay' => '',
			'autoplaytimeout' => 5000,
			'css_animation' => ''
		), $atts, 'vc_mad_testimonials');

		$this->query_entries();
		return $this->html();
	}

	public function query_entries() {
		$params = $this->atts;
		$page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' );
		if (!$page || $params['pagination'] == 'no') $page = 1;

		$tax_query = array();

		if ( !empty($params['categories']) ) {
			$categories = explode(',', $params['categories']);
			$tax_query = array(
				'relation' => 'AND',
				array(
					'taxonomy' => 'testimonials_category',
					'field' => 'id',
					'terms' => $categories
				)
			);
		}

		$query = array(
			'post_type' => 'testimonials',
			'orderby' => $params['orderby'],
			'order' => $params['order'],
			'paged' => $page,
			'posts_per_page' => $params['items'],
			'tax_query' 	 => $tax_query
		);

		$this->entries = new WP_Query($query);
	}

	public function html() {

		if ( empty($this->entries) || empty($this->entries->posts) ) return;

		$params = $this->atts;
		$wrapper_attributes = array();
		$layout = $items = $categories = $author_color = $orderby = $order = $style = $style_author = $autoplay = $autoplaytimeout = $style2 = '';

		$title = $tag_title = $type = $columns = $filter = $pagination = '';
		$description = !empty($params['description']) ? $params['description'] : '';
		$title_color = !empty($params['title_color']) ? $params['title_color'] : '';
		$author_color = !empty($params['author_color']) ? $params['author_color'] : '#999';
		$description_color = !empty($params['description_color']) ? $params['description_color'] : '';
		$css_animation = !empty($params['css_animation']) ? $params['css_animation'] : '';
		
		$title_align = !empty($params['title_align']) ? $params['title_align'] : '';
		$description_align = !empty($params['description_align']) ? $params['description_align'] : '';

		extract($this->atts);

		$custom_links = ( '||' === $link ) ? '' :$link;
		$custom_links = vc_build_link( $link );
		$use_link = false;
		if ( strlen( $custom_links['url'] ) > 0 ) {
			$use_link = true;
			$a_href = $custom_links['url'];
			$a_title = $custom_links['title'];
			$a_target = $custom_links['target'];
			$a_rel = $custom_links['rel'];
		}
		
		if ( isset($divider_color) && !empty($divider_color) ) {
			$divider_color = 'style="' . vc_get_css_color( 'background', $divider_color ) . '"';
		}
		
		$css_classes = array(
			'wpb_content_element testimonials_block', $layout
		);
		$css_class = preg_replace( '/\s+/', ' ', implode( ' ', array_filter( $css_classes ) ) );
		$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';

		if ( '' !== $css_animation ) {
			$wrapper_attributes[] = Jogasana_Helper::create_data_string_animation( $css_animation, 0, 0 );
		}
		
		if ( $title_color ) {
			$style = 'style="' . vc_get_css_color( 'color', $title_color ) . '"';
		}
		if ( $description_color ) {
			$style2 = 'style="' . vc_get_css_color( 'color', $description_color ) . '"';
		}
		
		if ( $author_color ) {
			$style_author = 'style="' . vc_get_css_color( 'color', $author_color ) . '"';
		}

		ob_start(); ?>

		<div <?php echo implode( ' ', $wrapper_attributes ) ?> >

			<?php if ( $subtitle != '' ): ?>
        	<div class="section-pre-title  <?php echo esc_attr($description_align) ?>" <?php echo sprintf('%s', $style2) ?>><?php echo esc_html($subtitle) ?></div>
            <?php endif; ?>
			
			
			<?php if ( $title != '' ) { ?>
			
				<?php
				echo Jogasana_Vc_Config::getParamTitle(
					array(
						'title' => $title,
						'tag_title' => $tag_title,
						'description' => $description,
						'title_color' => $title_color,
						'align' => $title_align,
						'align_des' => $description_align,
						'description_color' => $description_color,
					)
				);
				?>
			
				<?php	
				if ( $divider ) {	
				echo '<div class="icon-divider '. esc_attr($title_align) .'" ><i '. sprintf('%s', $divider_color) .' class="svg divider1"></i></div>';
				}
				 ?>
				
			<?php } ?>
			
			
			<?php $counter = 0; ?>

				<?php if ( $layout == 'type-1' ): ?>

					<div class="testimonial-holder style-3">
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						?>
						
						<div class="testimonial">

							<blockquote class="blockquote_custom" ><?php echo do_shortcode($content); ?></blockquote>
							
							<div class="author-box">
							<span class="author-icon"><i class="svg"></i></span>
							<div class="author-info">
								<div class="author"><?php echo esc_html($author) ?></div>
								<a href="<?php echo esc_url($link); ?>" class="author-position"  <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
							</div>
							</div>
							
						</div>

					<?php endforeach; ?>
                    </div>
					
				<?php elseif ( $layout == 'type-2' ): ?>

					<div class="testimonial-holder style-3 var2">
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						?>
						
						<div class="testimonial">

							<blockquote class="blockquote_custom" >
							<h5 class="title"><?php echo esc_html($title_t) ?></h5>
							<?php echo do_shortcode($content); ?>
							</blockquote>
							
							<div class="author-box">
							<span class="author-icon"><i class="svg"></i></span>
							<div class="author-info">
								<div class="author"><?php echo esc_html($author) ?></div>
								<a href="<?php echo esc_url($link); ?>" class="author-position" <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
							</div>
							</div>
							
						</div>

					<?php endforeach; ?>
                    </div>	

				<?php elseif ( $layout == 'type-3' ): ?>

				<div class="carousel-type-2 text-color-light">
				<div class="<?php if( count($this->entries->posts) > 3 ) { echo 'owl-carousel'; } else { echo 'no-owl-carousel'; }  ?>   testimonial-holder" data-max-items="<?php echo esc_attr($params['columns']); ?>" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-timeout="<?php echo esc_attr($autoplaytimeout); ?>">
				
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$counter++;
						?>
						<div class="item-carousel testimonial bg<?php echo esc_attr($counter) ?>">
							<blockquote class="blockquote_custom" >
							
							    <?php echo do_shortcode($content); ?>
								
								<div class="author-box">
						  
								  <span class="author-icon"><i class="svg"></i></span>
								  <div class="author-info">
									<div class="author"><?php echo esc_html($author) ?></div>
									<a href="<?php echo esc_url($link); ?>" class="author-position" <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
								  </div>

								</div>
								
							</blockquote>	
						</div>

					<?php 
					if($counter == 3) {
							$counter = 0;
						}
						
					endforeach; 
					?>
					
					</div>
					</div>
					
					<?php elseif ( $layout == 'type-4' ): ?>

				<div class="carousel-type-1">
				<div class="owl-carousel testimonial-holder style-2" data-max-items="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-timeout="<?php echo esc_attr($autoplaytimeout); ?>">
				
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$alt = trim(strip_tags(get_post_meta($id, '_wp_attachment_image_alt', true)));
						if ( empty($alt) ) {
							$attachment = get_post($id);
							$alt = trim(strip_tags($attachment->post_title));
						}
						$thumbnail_atts = array(
							'title'	=> trim(strip_tags($entry->post_title)),
							'alt' => $alt
						);
						?>
						<div class="item-carousel">
						<div class="testimonial">
                        
                        	<blockquote class="blockquote_custom" >
							<h5 class="title"><?php echo esc_html($title_t) ?></h5>
							<?php echo do_shortcode($content); ?>
							</blockquote>
							
								<div class="author-box">
						  
								  <span class="author-icon"><i class="svg"></i></span>
								  <div class="author-info">
									<div class="author"><?php echo esc_html($author) ?></div>
									<a href="<?php echo esc_url($link); ?>" class="author-position" <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
								  </div>

								</div>
                           
						</div>
						</div>

					<?php endforeach; ?>
					
					</div>
                    </div>
				
				<?php elseif ( $layout == 'type-4 light_style' ): ?>

				<div class="carousel-type-1">
				<div class="owl-carousel testimonial-holder style-2" data-max-items="1" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-timeout="<?php echo esc_attr($autoplaytimeout); ?>">
				
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$alt = trim(strip_tags(get_post_meta($id, '_wp_attachment_image_alt', true)));
						if ( empty($alt) ) {
							$attachment = get_post($id);
							$alt = trim(strip_tags($attachment->post_title));
						}
						$thumbnail_atts = array(
							'title'	=> trim(strip_tags($entry->post_title)),
							'alt' => $alt
						);
						?>
						<div class="item-carousel">
						<div class="testimonial">
                        
                        	<blockquote class="blockquote_custom" >
							<h5 class="title"><?php echo esc_html($title_t) ?></h5>
							<?php echo do_shortcode($content); ?>
							</blockquote>
							
								<div class="author-box">
						  
								  <span class="author-icon"><i class="svg"></i></span>
								  <div class="author-info">
									<div class="author"><?php echo esc_html($author) ?></div>
									<a href="<?php echo esc_url($link); ?>" class="author-position" <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
								  </div>

								</div>
                           
						</div>
						</div>

					<?php endforeach; ?>
					
					</div>
                    </div>
				<?php elseif ( $layout == 'type-5' ): ?>

				<div class="carousel-type-2">
				<div class="<?php if( count($this->entries->posts) > 3 ) { echo 'owl-carousel'; } else { echo 'no-owl-carousel'; }  ?>  testimonial-holder style-3" data-max-items="<?php echo esc_attr($params['columns']); ?>" data-item-margin="30" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-timeout="<?php echo esc_attr($autoplaytimeout); ?>">
				
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = has_excerpt($id) ? apply_filters( 'the_excerpt', $entry->post_excerpt ) : $entry->post_content;
						$alt = trim(strip_tags(get_post_meta($id, '_wp_attachment_image_alt', true)));
						if ( empty($alt) ) {
							$attachment = get_post($id);
							$alt = trim(strip_tags($attachment->post_title));
						}
						$thumbnail_atts = array(
							'title'	=> trim(strip_tags($entry->post_title)),
							'alt' => $alt
						);
						?>
						<div class="item-carousel">
						<div class="testimonial">
						
							<blockquote class="blockquote_custom" >
							<?php echo do_shortcode($content); ?>
							</blockquote>
							
                                <div class="author-box">
						  
								  <span class="author-icon"><i class="svg"></i></span>
								  <div class="author-info">
									<div class="author"><?php echo esc_html($author) ?></div>
									<a href="<?php echo esc_url($link); ?>" class="author-position" <?php echo sprintf('%s', $style_author) ?> ><?php echo esc_html($position) ?></a>
								  </div>

								</div>
                            
						</div>
						</div>

					<?php endforeach; ?>
					
					</div>
					</div>
					
				<?php elseif ( $layout == 'type-6' ): ?>

				<div class="carousel-type-2 var2">
				<div class="owl-carousel" data-max-items="2" data-item-margin="30" data-autoplay="<?php echo esc_attr($autoplay); ?>" data-timeout="<?php echo esc_attr($autoplaytimeout); ?>">
				
					<?php foreach ( $this->entries->posts as $entry ):
						$id = $entry->ID;
						$title_t = get_the_title($id);
						$link  = get_permalink($id);
						$author = get_post_meta($id, 'jogasana_t_author', true);
						$position = get_post_meta($id, 'jogasana_t_position', true);
						$content = $entry->post_content;
						$content = preg_replace( '|^\s*(https?://[^\s"]+)\s*$|im', "[embed]$1[/embed]", strip_tags($content));
						preg_match("!\[embed.+?\]|\[video.+?\]!", $content, $match_video);
						$this_post_content = '';
						
						if ( !empty($match_video) ) {
							global $wp_embed;
							$video = $match_video[0];

							$this_post_content = "<div class='ys-responsive-iframe responsive-iframe'>";
								$this_post_content .= do_shortcode($wp_embed->run_shortcode($video));
							$this_post_content .= "</div>";
						} else {
							preg_match("!\[(?:)?vc_video.+?\]!", $this_post_content, $match_video);

							if (!empty($match_video)) {
								$video = $match_video[0];
								$this_post_content = "<div class='ys-responsive-iframe responsive-iframe'>";
								$this_post_content .= do_shortcode($video);
								$this_post_content .= "</div>";
							}
						}
						
						$alt = trim(strip_tags(get_post_meta($id, '_wp_attachment_image_alt', true)));
						if ( empty($alt) ) {
							$attachment = get_post($id);
							$alt = trim(strip_tags($attachment->post_title));
						}
						$thumbnail_atts = array(
							'title'	=> trim(strip_tags($entry->post_title)),
							'alt' => $alt
						);
						?>
						<div class="item-carousel">
						<div class="testimonial">
						
							<?php echo sprintf( '%s', $this_post_content); ?>
					
						</div>
						</div>

					<?php endforeach; ?>
					
					</div>
					</div>
					
					<?php endif; ?>
				

						<?php if ( $use_link ) { 
								$attributes = array();
								$attributes[] = 'href="' . trim( $a_href ) . '"';
								$attributes[] = 'title="' . esc_attr( trim( $a_title ) ) . '"';
								if ( ! empty( $a_target ) ) {
									$attributes[] = 'target="' . esc_attr( trim( $a_target ) ) . '"';
								}
								if ( ! empty( $a_rel ) ) {
									$attributes[] = 'rel="' . esc_attr( trim( $a_rel ) ) . '"';
								}
								$attributes = implode( ' ', $attributes );
					
								if ( $layout == 'type-1' ) { 
								echo '<div class="testimonials-btn"><a class="btn btn-style-2" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								} elseif ( $layout == 'type-1' ) { 
								echo '<div class="testimonials-btn"><a class="btn btn-style-2" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								} elseif ( $layout == 'type-3' ) { 
								echo '<div class="testimonials-btn"><a class="btn btn-style-2" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								} elseif ( $layout == 'type-4' ) { 
								echo '<div class="testimonials-btn"><a class="btn btn-style-2" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								} elseif ( $layout == 'type-5' ) { 
								echo '<div class="testimonials-btn"><a class="btn btn-style-2" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								} elseif ( $layout == 'type-6' ) { 
								echo '<div class="testimonials-btn align-center"><a class="btn btn-style-6" ' . $attributes . '>' . esc_html($a_title) . '</a></div>';
								}
						} ?>
				
		</div>		

		<?php return ob_get_clean();
	}

}