<?php
if (!class_exists('JOGASANA_WOOCOMMERCE_CONFIG')) {

	class JOGASANA_WOOCOMMERCE_CONFIG {

		protected static $_instance = null;

		public $paths = array();
		public static $pathes = array();

		public function path($name, $file = '') {
			return $this->paths[$name] . (strlen($file) > 0 ? '/' . preg_replace('/^\//', '', $file) : '');
		}

		public function assetUrl($file) {
			return $this->paths['BASE_URI'] . $this->path('ASSETS_DIR_NAME', $file);
		}

		function __construct() {

			// Woocommerce support
			add_theme_support('woocommerce');
			add_theme_support('wc-product-gallery-slider');
			add_theme_support( 'wc-product-gallery-lightbox' );
			
			$dir = get_template_directory() . '/config-woocommerce';

			define('JOGASANA_WOO_CONFIG', true);

			$this->paths = array(
				'PHP' => $dir . '/php/',
				'ASSETS_DIR_NAME' => 'assets',
				'BASE_URI' => get_template_directory_uri() . '/config-woocommerce/'
			);
			self::$pathes = $this->paths;

			include( $this->paths['PHP'] . 'new-badge.class.php' );

			$this->woocommerce_remove_hooks();
			$this->woocommerce_add_filters();
			$this->woocommerce_add_hooks();
			
			add_action('backend_theme_activation', array(&$this, 'pre_woocommerce_settings'), 10);

			add_action('wp_enqueue_scripts', array(&$this, 'add_enqueue_scripts'));
			add_action('admin_init', array(&$this, 'admin_init'));
			add_action('widgets_init', array(&$this, 'include_widgets'));
		}

		public function admin_init() {
			add_filter("manage_product_posts_columns", array(&$this, "manage_columns"));
		}

		public function include_widgets() {
			$before_widget = '<div id="%1$s" class="widget %2$s">';

			$widget_args = array(
				'before_widget' => $before_widget,
				'after_widget' => '</div>',
				'before_title' => '<h6 class="ys-widget-title widget-title">',
				'after_title' => '</h6>'
			);

			// Shop Widget Area
			register_sidebar(array(
				'name' => esc_html__('Shop Widget Area', 'jogasana'),
				'id' => 'shop-widget-area',
				'description'   => esc_html__('For WooCommerce pages.', 'jogasana'),
				'before_widget' => $widget_args['before_widget'],
				'after_widget' => $widget_args['after_widget'],
				'before_title' => $widget_args['before_title'],
				'after_title' => $widget_args['after_title']
			));
		}

		public function custom_get_option($key = false, $default = "") {

			$result = get_option('jogasana_options');

			if (is_array($key)) {
				$result = $result[$key[0]];
			} else {
				$result = $result['jogasana'];
			}

			if ($key === false) {
			} else if(isset($result[$key])) {
				$result = $result[$key];
			} else {
				$result = $default;
			}

			if ($result == "") { $result = $default; }
			return $result;
		}

		public function woocommerce_add_filters() {
			add_filter('woocommerce_enqueue_styles', '__return_empty_array');
			add_filter('woocommerce_general_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_page_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_catalog_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_inventory_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_shipping_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_tax_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('woocommerce_product_settings', array(&$this, 'woocommerce_general_settings_filter'));
			add_filter('loop_shop_columns', array(&$this, 'woocommerce_loop_columns'));
			add_filter('loop_shop_per_page', array(&$this, 'woocommerce_product_count'));
			add_filter( 'woocommerce_show_page_title', '__return_false' );
			add_filter( 'woocommerce_loop_add_to_cart_args', array(&$this, 'filter_woocommerce_loop_add_to_cart_args'), 10, 2 );
		}
		
		function filter_woocommerce_loop_add_to_cart_args( $args, $product ) {
			$args['class'] .= ' btn btn-small btn-style-3';
			return $args;
		}
		
		function woocommerce_general_settings_filter($options) {
			$delete = array('woocommerce_enable_lightbox');

			foreach ($options as $key => $option) {
				if (isset($option['id']) && in_array($option['id'], $delete)) {
					unset($options[$key]);
				}
			}
			return $options;
		}
	
		public function woocommerce_remove_hooks() {

			//template content-product
			remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
			remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 ); 
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
			remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );  
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );  
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );  
			remove_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10 );  

			//template archive-product
			remove_action('woocommerce_before_subcategory_title', 'woocommerce_subcategory_thumbnail', 10);
			remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
			
			//page shop
			remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0);
			remove_action('woocommerce_sidebar', 'woocommerce_get_sidebar', 10);
					
			//single product
			remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10);
			remove_action( 'woocommerce_review_before', 'woocommerce_review_display_gravatar', 10 );
		
		}

		public function woocommerce_add_hooks() {

			add_action( 'init', array(&$this, 'woocommerce_clear_cart_url'));

			/* Content Product Hooks */
			add_action( 'woocommerce_before_shop_loop_item_title', array($this, 'template_loop_product_thumbnail') );
			add_action( 'woocommerce_shop_loop_item_title', array($this, 'template_loop_product_title') );
			add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 10 );  
			add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 5 );  
			add_action( 'woocommerce_after_shop_loop_item', array($this, 'template_after_shop_loop_item'), 15 );  
			add_action( 'woocommerce_after_shop_loop_item_title', array($this, 'template_after_shop_loop_item_title'), 15 );  
			add_action( 'woocommerce_after_shop_loop', array($this, 'template_woocommerce_pagination'), 10 );
			
			////page shop
			add_action('woocommerce_archive_description', array(&$this, 'woocommerce_category_image'), 2);
			add_action('woocommerce_archive_description', array(&$this, 'woocommerce_subcategory_image'), 10);
			
			// single product
			if ( class_exists('Jogasana_Functionality') ) { 
			add_action( 'woocommerce_share', array(&$this, 'jogasana_product_share'),10);
			}
			
			add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs',10);
			add_action( 'woocommerce_review_before', array(&$this, 'jogasana_woocommerce_review_display_gravatar'), 10 );

		}
		
		public function template_woocommerce_pagination() {
			echo  jogasana_pagination();
		}
		
		public function template_after_shop_loop_item() {
			echo '</div>';
		}
		
		public function template_after_shop_loop_item_title() {
			echo '</div>';
		}
		
		public function jogasana_woocommerce_review_display_gravatar( $comment ) {
				echo get_avatar( $comment, apply_filters( 'woocommerce_review_gravatar_size', '100' ), '' );
		}

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function manage_columns($columns) {
			unset($columns['wpseo-title']);
			unset($columns['wpseo-metadesc']);
			unset($columns['wpseo-focuskw']);

			return $columns;
		}

		public function woocommerce_loop_columns() {
			global $jogasana_settings;

			$woocommerce_columns = 3;
			if(!empty($jogasana_settings['shop-product-cols'])) {
			$woocommerce_columns = $jogasana_settings['shop-product-cols'];
			}
			
			return $woocommerce_columns;
		}

		public function woocommerce_product_count() {
			global $jogasana_settings;
			
			$count = 12;
			if(!empty($jogasana_settings['shop-count-item'])) {
			$count = $jogasana_settings['shop-count-item'];
			}
			
			return $count;
		}

		public function woocommerce_clear_cart_url() {
			global $woocommerce;

			if ( isset( $_GET['empty-cart'] ) ) {
				$woocommerce->cart->empty_cart();
			}
		}

		public function template_loop_product_title() {
			global $product;
			
			echo wc_get_product_category_list( $product->get_id(), ', ', '<span class="posted_in">', '</span>' );

			echo '<h6 class="product-name"><a href="'. esc_url(get_the_permalink()) .'">' . get_the_title() . '</a></h6>';
			echo '<div class="pricing-area">';
		}
		
		public function template_loop_product_thumbnail() {
			$this->product_thumbnail();
		}
		public function product_thumbnail() {
			global $post, $product;
			
			$shop_catalog = wc_get_image_size( 'shop_catalog' );

			$thumb_image = Jogasana_Helper::get_the_post_thumbnail( get_the_ID(), array($shop_catalog['width'] , $shop_catalog['height']), true, '', array( 'alt' => get_the_title() ) ); 
			?>

			<?php if ( $product->is_featured() ) : ?>

				<?php echo apply_filters( 'woocommerce_featured_flash', '<span class="label ys-featured">' . esc_html__( 'Featured!', 'jogasana' ) . '</span>', $post, $product ); ?>
				
			<?php endif; ?>
			
			<?php if ( has_post_thumbnail(get_the_ID()) && $thumb_image ): ?>
				 <div class="product-image">
                    <a href="<?php echo esc_url(get_the_permalink(get_the_ID())); ?>"><?php echo wp_kses_post($thumb_image); ?></a>

                  </div>
			<?php else: ?>
 				<div class="product-image placeholder_img">
                    <a href="<?php echo esc_url(get_the_permalink(get_the_ID())); ?>"><?php echo wc_placeholder_img( 'shop_catalog' ); ?></a>
   
                  </div>
			<?php endif; ?>
			
			<div class="product-description">
			<?php 
		}

		public function add_enqueue_scripts() {
			$css_file = $this->assetUrl('css/woocommerce-mod.css');
			$woo_mod_file = $this->assetUrl('js/woocommerce-mod.js');									
			wp_enqueue_style( 'jogasana-woocommerce-mod', $css_file );					
			wp_enqueue_script( 'jogasana-woocommerce-mod', $woo_mod_file, array('jquery', 'jogasana-plugins', 'jogasana-core'), 1, true );

			$goahead = 1;	
		}

		public static function enqueue_script($script) {
			wp_enqueue_script( 'jogasana-' . $script );
		}

		public static function content_truncate($string, $limit, $break = ".", $pad = "...") {
			if (strlen($string) <= $limit) { return $string; }

			if (false !== ($breakpoint = strpos($string, $break, $limit))) {
				if ($breakpoint < strlen($string) - 1) {
					$string = substr($string, 0, $breakpoint) . $pad;
				}
			}
			if (!$breakpoint && strlen(strip_tags($string)) == strlen($string)) {
				$string = substr($string, 0, $limit) . $pad;
			}
			return $string;
		}

		public static function create_data_string($data = array()) {
			$data_string = "";

			foreach($data as $key => $value) {
				if (is_array($value)) $value = implode(", ", $value);
				$data_string .= " data-$key={$value} ";
			}
			return $data_string;
		}

		function woocommerce_category_image() {
			if ( is_product_category() ) {
			
				global $wp_query;
				$cat = $wp_query->get_queried_object();
				$thumbnail_id = get_woocommerce_term_meta( $cat->term_id, 'thumbnail_id', true );
				$image = wp_get_attachment_url( $thumbnail_id );
				if ( $image ) {
					echo '<figure class="term-image entry-attachment">';
						echo '<img src="' . $image . '" />';
					echo '</figure>';
				}
				
				if ( is_tax( array( 'product_cat', 'product_tag' ) ) && get_query_var( 'paged' ) == 0 ) {
				  $description = wc_format_content( term_description() );
				  if ( $description ) {
					echo '<div class="term-description content-element3">' . $description . '</div>';
				  }
				}
			
			}
		}

		function woocommerce_subcategory_image() {
			if ( is_product_category() ) {
				global $wp_query;
				
				woocommerce_product_subcategories(array( 'before' => '<div class="product_subcategories content-element2"><ul>', 'after' => '</ul></div>'));
				
			}
		}

		function woocommerce_default_product_tabs( $tabs = array() ) {
			global $product, $post;

			// Description tab - shows product content
			if ( $post->post_excerpt ) {
				$tabs['description'] = array(
					'title'    => esc_html__( 'Description', 'jogasana' ),
					'priority' => 10,
					'callback' => 'woocommerce_product_description_tab'
				);
			}

			// Additional information tab - shows attributes
			if ( $product && ( $product->has_attributes() || ( $product->enable_dimensions_display() && ( $product->has_dimensions() || $product->has_weight() ) ) ) ) {
				$tabs['additional_information'] = array(
					'title'    => esc_html__( 'Additional Information', 'jogasana' ),
					'priority' => 20,
					'callback' => 'woocommerce_product_additional_information_tab'
				);
			}

			// Reviews tab - shows comments
			if ( comments_open() ) {
				$tabs['reviews'] = array(
					'title'    => sprintf( esc_html__( 'Reviews (%d)', 'jogasana' ), $product->get_review_count() ),
					'priority' => 30,
					'callback' => 'comments_template'
				);
			}

			return $tabs;
		}
		
		public function jogasana_product_share() {
			
			$post_id = get_the_ID();
			$image = esc_url(wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ));
			$permalink = esc_url( apply_filters('the_permalink', get_the_permalink( $post_id )) );
			$title = esc_attr(get_the_title( $post_id ));
			$extra_attr = 'target="_blank"';

			global $jogasana_settings;
			
			if ( !$jogasana_settings['product-single-share'] ) return;
			
			echo '<div class="share-wrap var2">';
			?>
			
			<span class="share-title"><?php echo esc_html__('Share this:', 'jogasana') ?></span>
				<ul class="social-icons share">

					<li><a class="sh-facebook" href="https://www.facebook.com/sharer/sharer.php?u<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-facebook"></i></a></li>
				
					<li><a class="sh-twitter" href="https://twitter.com/intent/tweet?text=<?php echo urlencode(esc_attr($title)) ?>&amp;url=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-twitter"></i></a></li>
				
					
					<li><a class="sh-pinterest" href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url($permalink) ?>&amp;media=<?php echo esc_url($image) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-pinterest"></i></a></li>
				
					<li><a class="sh-mail" href="mailto:?subject=<?php echo urlencode(esc_attr($title)) ?>&amp;body=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-mail"></i></a></li>
					
				</ul>
			
			<?php 
			echo '</div>';
			
		}
		
		public static function is_realy_woocommerce_page () {
			if(  function_exists ( "is_woocommerce" ) && is_woocommerce()){
					return true;
			}
			$woocommerce_keys   =   array ( "woocommerce_shop_page_id" ,
											"woocommerce_terms_page_id" ,
											"woocommerce_cart_page_id" ,
											"woocommerce_checkout_page_id" ,
											"woocommerce_pay_page_id" ,
											"woocommerce_thanks_page_id" ,
											"woocommerce_myaccount_page_id" ,
											"woocommerce_edit_address_page_id" ,
											"woocommerce_view_order_page_id" ,
											"woocommerce_change_password_page_id" ,
											"woocommerce_logout_page_id" ,
											"woocommerce_lost_password_page_id" ) ;
			foreach ( $woocommerce_keys as $wc_page_id ) {
					if ( get_the_ID () == get_option ( $wc_page_id , 0 ) ) {
							return true ;
					}
			}
			return false;
		}
		
		public static function jogasana_is_product() {
			return is_singular( array( 'product' ) );
		}
		
		public static function jogasana_is_shop_installed() {
			global $woocommerce;
			if ( isset( $woocommerce ) ) {
				return true;
			} else {
				return false;
			}
		}
		
		public static function jogasana_is_product_category( $term = '' ) {
			return is_tax( 'product_cat', $term );
		}

		public static function jogasana_wc_get_page_id( $page ) {

			if ( $page == 'pay' || $page == 'thanks' ) {
				_deprecated_argument( __FUNCTION__, '2.1', 'The "pay" and "thanks" pages are no-longer used - an endpoint is added to the checkout instead. To get a valid link use the WC_Order::get_checkout_payment_url() or WC_Order::get_checkout_order_received_url() methods instead.' );

				$page = 'checkout';
			}
			if ( $page == 'change_password' || $page == 'edit_address' || $page == 'lost_password' ) {
				_deprecated_argument( __FUNCTION__, '2.1', 'The "change_password", "edit_address" and "lost_password" pages are no-longer used - an endpoint is added to the my-account instead. To get a valid link use the wc_customer_edit_account_url() function instead.' );

				$page = 'myaccount';
			}

			$page = apply_filters( 'woocommerce_get_' . $page . '_page_id', get_option('woocommerce_' . $page . '_page_id' ) );

			return $page ? absint( $page ) : -1;
		}

		
		public static function jogasana_is_shop() {
			return is_post_type_archive( 'product' ) || is_page( self::jogasana_wc_get_page_id( 'shop' ) );
		}
		
		public function pre_woocommerce_settings() {

			$catalog = array(
				'width' 	=> '360',
				'height'	=> '360'
			);

			$single = array(
				'width' 	=> '654',
				'height'	=> '654'
			);

			$thumbnail = array(
				'width' 	=> '130',
				'height'	=> '130'
			);

			update_option('shop_catalog_image_size', $catalog);
			update_option('shop_single_image_size', $single);
			update_option('shop_thumbnail_image_size', $thumbnail);
		
		}

	}
}