<?php
/**
 * Jogasana functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @package WordPress
 * @since Jogasana 1.0
 */



/**
 * Include the main Jogasana class.
 */
require_once( get_template_directory() . '/includes/class-jogasana.php' );

function Jogasana() {
	return Jogasana::get_instance();
}
Jogasana();

/* 	Basic Settings
/* ---------------------------------------------------------------------- */

require_once( get_theme_file_path('includes/functions.php') );

/*  Add Widgets
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('includes/widgets.php') );

/* Load Base Functions
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('includes/helpers/theme-helper.php') );
require_once( get_theme_file_path('includes/helpers/post-format-helper.php') );
require_once( get_theme_file_path('includes/classes/register-admin-user-profile.class.php') );
require_once( get_theme_file_path('includes/classes/class-jogasana-walker-comment.php') );
require_once( get_theme_file_path('includes/functions-base.php') );

/*  Load Functions Files
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('includes/functions-core.php') );

/*  Include Config Composer
/* ---------------------------------------------------------------------- */

if ( class_exists('Vc_Manager') ) {
	require_once( get_theme_file_path('config-composer/config.php') );
}

/*  Include Config WooCommerce 
/* ---------------------------------------------------------------------- */
if (class_exists('WooCommerce')) {
	if ( ! function_exists('jogasana_woo_config') ) {
		function jogasana_woo_config() {
			require_once( get_theme_file_path('config-woocommerce/config.php') );
			return JOGASANA_WOOCOMMERCE_CONFIG::instance();
		}
	}

	global $jogasana_woo_config;
	
	WC()->query->layered_nav_product_ids =array();	
	$jogasana_woo_config = jogasana_woo_config();
}

/* Load Login With Ajax compatibility file
/* ---------------------------------------------------------------------- */



if ( class_exists( 'LoginWithAjax' ) ) {
	require_once( get_theme_file_path('includes/login-with-ajax.php') );
}


if ( ! function_exists( 'jogasana_theme_add_editor_styles' ) ) {
		function jogasana_theme_add_editor_styles() {
			add_editor_style( 'custom-editor-style.css' );
		}
	}
add_action( 'init', 'jogasana_theme_add_editor_styles' );

/*  Theme support & Theme setup
/* ---------------------------------------------------------------------- */

if ( ! function_exists( 'jogasana_setup' ) ) :
	function jogasana_setup() {

		$GLOBALS['content_width'] = apply_filters( 'jogasana_content_width', 1140 );

		// Load theme textdomain
		load_theme_textdomain( 'jogasana', get_template_directory()  . '/lang' );
		load_child_theme_textdomain( 'jogasana', get_stylesheet_directory() . '/lang' );

		/**
		 * Jogasana admin options
		 */

		require_once( get_theme_file_path('admin/framework/admin.php') );
		jogasana_check_theme_options();
		global $pagenow;

		// Post Formats Support
		add_theme_support('post-formats', array( 'gallery', 'quote', 'video', 'audio', 'link' ));

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'script', 
			'style'
		) );
		
		// Post Thumbnails Support
		add_theme_support('post-thumbnails');
		add_image_size( 'jogasana-post-small', 334, 312, true );
		add_image_size( 'jogasana-post-big', 698, 442, true );
		add_image_size( 'jogasana-post-full', 1140, 600, true );
		add_image_size( 'jogasana-masonry1', 450, 286, true );
		add_image_size( 'jogasana-masonry2', 450, 468, true );
		add_image_size( 'jogasana-masonry3', 450, 624, true );
		add_image_size( 'jogasana-gallery-grid', 555, 442, true );
		add_image_size( 'jogasana-gallery-small', 360, 286, true );
		add_image_size( 'jogasana-thumbnail', 100, 78, true );

		// Add default posts and comments RSS feed links to head
		add_theme_support('automatic-feed-links');
		add_theme_support('title-tag');

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', esc_html__('Primary Menu','jogasana') );
		register_nav_menu( 'footer',  esc_html__('Footer Menu','jogasana') );
		register_nav_menu( 'header5',  esc_html__('Header 5 Menu','jogasana') );
		add_theme_support( 'custom-header', apply_filters( 'jogasana_custom_header_args', array(
				'width'                  => 1140,
			) ) );
			
		// Setup the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'jogasana_custom_background_args', array(
				'default-color'      => '#fff',
				'default-attachment' => 'fixed',
			) ) );

		remove_action('wp_head', 'rsd_link');
		remove_post_type_support( 'page', 'thumbnail' );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	}
endif;
add_action( 'after_setup_theme', 'jogasana_setup', 100 );

/*  Layouts
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('includes/layout.php') );

/*  Load hooks
/* ---------------------------------------------------------------------- */
if ( !is_admin() ) {
	require_once( get_theme_file_path('includes/templates-hooks.php') );
}

/*  Custom template tags for this theme.
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('includes/template-tags.php') );

/*  Include Plugins
/* ---------------------------------------------------------------------- */
require_once( get_theme_file_path('admin/plugin-bundle.php') );
require_once( get_theme_file_path('config-plugins/config.php') );

/*  Include Config DHVC Forms
/* ---------------------------------------------------------------------- */

if ( defined('WPCF7_VERSION') ) {
	require_once( get_theme_file_path('config-contact-form-7/config.php') );
}

/*  Include Config WPML
/* ---------------------------------------------------------------------- */

if ( defined('ICL_SITEPRESS_VERSION') && defined('ICL_LANGUAGE_CODE') ) {
	require_once( get_theme_file_path('config-wpml/config.php') );
}

/*  Get user name
/* ---------------------------------------------------------------------- */

if ( !function_exists("jogasana_get_user_name") ) {

	function jogasana_get_user_name($current_user) {

		if ( !$current_user->user_firstname && !$current_user->user_lastname ) {
			$user_name = $current_user->user_nicename;
		} else {
			$user_name = $current_user->user_firstname . ' ' . $current_user->user_lastname;
		}
		return $user_name;
	}

}

function jogasana_wpcodex_add_excerpt_support_for_pages() {
	add_post_type_support( 'page', 'excerpt' );
}
add_action( 'init', 'jogasana_wpcodex_add_excerpt_support_for_pages' );


if ( ! function_exists( 'jogasana_tag_cloud_widget' ) ) { 
	function jogasana_tag_cloud_widget($args) {
		$args['number'] = 12; 
		$args['largest'] = 12; 
		$args['smallest'] = 12; 
		$args['unit'] = 'px'; 
		$args['format'] = 'flat'; 
		$args['separator'] = ''; 
		return $args;
	}
}
add_filter( 'widget_tag_cloud_args', 'jogasana_tag_cloud_widget' );

if ( ! function_exists( 'jogasana_tag_cloud_widget1' ) ) { 
	function jogasana_tag_cloud_widget1($args) {
		$args['number'] = 12; 
		$args['largest'] = 12; 
		$args['smallest'] = 12; 
		$args['unit'] = 'px'; 
		$args['format'] = 'flat'; 
		$args['separator'] = ''; 
		return $args;
	}
}
add_filter( 'woocommerce_product_tag_cloud_widget_args', 'jogasana_tag_cloud_widget1' );

/* Get Share Btn */
if ( ! function_exists( 'jogasana_base_post_share_btn' ) ) {
	function jogasana_base_post_share_btn($post_id, $share_title='') {
		return jogasana_base()->post_share_btn($post_id, $share_title);
	}
}

if ( ! function_exists( 'jogasana_removeDemoModeLink' ) ) {
function jogasana_removeDemoModeLink() { 
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}
add_action('init', 'jogasana_removeDemoModeLink');
}

if ( class_exists( 'Tribe__Events__Main' ) ) {
	
	if ( ! function_exists( 'jogasana_get_events_category' ) ) {
		function jogasana_get_events_category($id = null){
			$categories = get_the_terms( $id, 'tribe_events_cat' );
			$res = '';
			if(!empty($categories)){
				foreach ( $categories as $val ) {
					$res .= $val->slug;
					$res .= ', ';
				}
			}
			return  $res;
		}
	}

	if ( ! function_exists( 'jogasana_the_related_events' ) ) { 
	function jogasana_the_related_events ($post_num = 3, $category_post = null, $esclude_post = null, $post_class='welcome-col'){ 
		$post_id = '';
		$post_class = $post_class;
		global $post;
		$tmp_post = $post;

		$args = array( 'post_type' => 'tribe_events',				   
					   'exclude' => $esclude_post,
					   'meta_key' => '_EventStartDate',
					   'orderby' => '_EventStartDate',
					   'order'    => 'DESC',
					   'numberposts' => $post_num);
		$myposts = get_posts($args);

		if($myposts) {?>
		<div class="<?php echo esc_attr($post_class); ?>" data-isotope-options='{"itemSelector" : ".item","layoutMode" : "masonry","transitionDuration":"0.7s","masonry" : {"columnWidth":".item"}}'>
		
		<?php 	
		foreach( $myposts as $post ) : setup_postdata($post);
		?>
			
			<?php 
			$time_format = get_option( 'time_format', Tribe__Date_Utils::TIMEFORMAT );
			$time_range_separator = tribe_get_option('timeRangeSeparator', ' - ');
			$start_datetime = tribe_get_start_date();
			$start_date = tribe_get_start_date( null, false );
			$start_time = tribe_get_start_date( null, false, $time_format );
			$start_ts = tribe_get_start_date( null, false, Tribe__Date_Utils::DBDATEFORMAT );
			$end_datetime = tribe_get_end_date();
			$end_date = tribe_get_end_date( null, false );
			$end_time = tribe_get_end_date( null, false,  $time_format );
			$end_ts = tribe_get_end_date( null, false, Tribe__Date_Utils::DBDATEFORMAT );
			$address = tribe_address_exists() ? '' . tribe_get_full_address() . '' : '';
			$start_day = tribe_get_start_date( null, false, 'd' );
		    $start_month = tribe_get_start_date( null, false, 'M' );

			$event_id = $post->ID;
			$post_link = get_permalink($event_id);
			$thumb_image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'medium'); 
			$title1 = get_the_title($event_id);
			if($title1 == '') {
			$title1 = esc_html__('No Title', 'jogasana');
			}
			$venue_details = tribe_get_venue_details($event_id);	
			?>	

			<div <?php post_class('item'); ?>>
			
			<div class="entry">
				
				<div class="thumbnail-attachment">
					<a href="<?php echo esc_url( $post_link ); ?>"><img src="<?php echo esc_url($thumb_image_url[0]); ?>" alt="<?php the_title_attribute() ?>"></a>
				</div>
				
				<div class="entry-body">
					
						<h6 class="entry-title">
						<a href="<?php echo esc_url( $post_link ); ?>" title="<?php the_title_attribute() ?>" ><?php echo esc_html( $title1 ); ?></a>
						</h6>
						
						<div class="our-info vr-type">
							<div class="info-item">
								<i class="licon-clock3"></i>
								<div class="wrapper">
								<?php echo tribe_events_event_schedule_details($event_id) ?>
								</div>
							</div>
							<?php if ( $venue_details ) : ?>
							<div class="info-item">
								<i class="licon-map-marker"></i>
								<div class="wrapper">
								<?php
									$address_delimiter =' ';
									echo implode( $address_delimiter, $venue_details );
								?>
								</div>
							</div>
							<?php endif; ?>
						</div>	

				</div>

			</div>
			</div>

		
		<?php 
				
		endforeach;
		 ?>
		 </div>
		 
		<?php 
		$post = $tmp_post; 
		}
		}  
   }

}

add_filter('get_the_archive_title', function( $title ){
	return preg_replace('~^[^:]+: ~', '', $title );
});

add_action( 'template_redirect', function(){
    ob_start( function( $buffer ){
       $buffer = str_replace( array( ' type="text/javascript"', " type='text/javascript'" ), ' ', $buffer );
        $buffer = str_replace( array( 'type="text/css"', "type='text/css'" ), '', $buffer );
        $buffer = str_replace( array( "name='SmartPopup Schedule Time JS'", "name='SmartPopUp'" ), '', $buffer );
        return $buffer;
    });
});

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function jogasana_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'jogasana_pingback_header' );

/**
 * Returns information about the current post's discussion, with cache support.
 */
function jogasana_get_discussion_data() {
	static $discussion, $post_id;

	$current_post_id = get_the_ID();
	if ( $current_post_id === $post_id ) {
		return $discussion; /* If we have discussion information for post ID, return cached object */
	} else {
		$post_id = $current_post_id;
	}

	$comments = get_comments(
		array(
			'post_id' => $current_post_id,
			'orderby' => 'comment_date_gmt',
			'order'   => get_option( 'comment_order', 'asc' ), /* Respect comment order from Settings ยป Discussion. */
			'status'  => 'approve',
			'number'  => 20, /* Only retrieve the last 20 comments, as the end goal is just 6 unique authors */
		)
	);

	$authors = array();
	foreach ( $comments as $comment ) {
		$authors[] = ( (int) $comment->user_id > 0 ) ? (int) $comment->user_id : $comment->comment_author_email;
	}

	$authors    = array_unique( $authors );
	$discussion = (object) array(
		'authors'   => array_slice( $authors, 0, 6 ),           /* Six unique authors commenting on the post. */
		'responses' => get_comments_number( $current_post_id ), /* Number of responses. */
	);

	return $discussion;
}

// Disables the block editor from managing widgets in the Gutenberg plugin.
add_filter( 'gutenberg_use_widgets_block_editor', '__return_false' );

// Disables the block editor from managing widgets.
add_filter( 'use_widgets_block_editor', '__return_false' );
