<?php

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
 * The main theme class.
 */
class Jogasana {

	/**
	 * The template directory URL.
	 *
	 * @static
	 * @access public
	 * @var string
	 */
	public static $template_dir_url = '';

	/**
	 * The one, true instance of the Jogasana object.
	 *
	 * @static
	 * @access public
	 * @var null|object
	 */
	public static $instance = null;

	/**
	 * The theme version.
	 *
	 * @static
	 * @access public
	 * @var string
	 */
	public static $version = '1.0';

	/**
	 * Determine if we're currently upgrading/migration options.
	 *
	 * @static
	 * @access public
	 * @var bool
	 */
	public static $is_updating  = false;

	/**
	 * Bundled Plugins.
	 *
	 * @static
	 * @access public
	 * @var array
	 */
	public static $bundled_plugins = array();

	/**
	 * Jogasana_Product_registration
	 *
	 * @access public
	 * @var object Jogasana_Product_registration.
	 */
	public $registration;

	/**
	 * Access the single instance of this class.
	 *
	 * @return Jogasana
	 */
	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new Jogasana();
		}
		return self::$instance;
	}

	/**
	 * The class constructor
	 */
	private function __construct() {

		// Initialize bundled plugins array.
		self::$bundled_plugins = array(
			'revolution' => array( 'slug' => 'revslider', 'name' => esc_html__('Slider Revolution', 'jogasana'), 'source' => 'revslider.zip', 'version' => '5.3.1.5' ),
			'mega_main_menu' => array( 'slug' => 'mega_main_menu', 'name' => esc_html__('Mega main menu', 'jogasana'), 'source' => 'mega_main_menu.zip', 'version' => '2.1.4' ),
			'theme_functionality' => array( 'slug' => 'jogasana-theme-functionality', 'name' => esc_html__('Jogasana Theme Functionality', 'jogasana'), 'source' => 'jogasana-theme-functionality.zip', 'version' => '1.0' ),
			'easy_tables' => array( 'slug' => 'easy-tables-vc', 'name' => esc_html__('Easy Tables (vc)', 'jogasana'), 'source' => 'easy-tables-vc.zip', 'version' => '1.0.10' ),
			'composer' => array( 'slug' => 'js_composer', 'name' => esc_html__('WPBakery Visual Composer', 'jogasana'), 'source' => 'js_composer.zip', 'version' => '5.2.1' ),
			'vc_addons' => array( 'slug' => 'Ultimate_VC_Addons', 'name' => esc_html__('Ultimate Addons for Visual Composer', 'jogasana'), 'source' => 'Ultimate_VC_Addons.zip', 'version' => '3.16.5' ),
			'sumosubscriptions' => array( 'slug' => 'sumosubscriptions', 'name' => esc_html__('SUMO Subscriptions', 'jogasana'), 'source' => 'sumosubscriptions.zip', 'version' => '' ),
			'sumomemberships' => array( 'slug' => 'sumomemberships', 'name' => esc_html__('SUMO Memberships', 'jogasana'), 'source' => 'sumomemberships.zip', 'version' => '' ),
			'indeed_smart_popup' => array( 'slug' => 'indeed-smart-popup', 'name' => esc_html__('Indeed Smart PopUp', 'jogasana'), 'source' => 'indeed-smart-popup.zip', 'version' => '' ),
		);

	}

	/**
	 * Gets the theme version.
	 *
	 * @since 5.0
	 *
	 * @return string
	 */
	public static function get_theme_version() {
		return self::$version;
	}

	/**
	 * Gets the bundled plugins.
	 *
	 * @since 5.0
	 *
	 * @return array Array of bundled plugins.
	 */
	public static function get_bundled_plugins() {
		return self::$bundled_plugins;
	}

}