<?php
/**
 * This class outputs custom comment walker for HTML5 friendly WordPress comment and threaded replies.
 *
 * @since 1.0.0
 */
class Jogasana_Walker_Comment extends Walker_Comment {

	/**
	 * Outputs a comment in the HTML5 format.
	 *
	 * @see wp_list_comments()
	 *
	 * @param WP_Comment $comment Comment to display.
	 * @param int        $depth   Depth of the current comment.
	 * @param array      $args    An array of arguments.
	 */
	protected function html5_comment( $comment, $depth, $args ) {

		$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';

		?>
		<<?php echo $tag; ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( $this->has_children ? 'parent ys-comment' : 'ys-comment', $comment ); ?>>
			
			<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
				
				
					<div class="ys-gravatar gravatar comment-author vcard">
						<?php
						$comment_author_link = get_comment_author_link( $comment );
						$comment_author_url  = get_comment_author_url( $comment );
						$comment_author      = get_comment_author( $comment );
						$avatar              = get_avatar( $comment, $args['avatar_size'] );
						if ( 0 != $args['avatar_size'] ) {
							if ( empty( $comment_author_url ) ) {
								echo $avatar;
							} else {
								printf( '<a href="%s" rel="external nofollow" class="url">', $comment_author_url );
								echo $avatar;
							}
						}

						if ( ! empty( $comment_author_url ) ) {
							echo '</a>';
						}
						?>
					</div>

					<div class="ys-comment-body comment-body">

						<header class="ys-comment-meta comment-meta">

							<h6 class="ys-comment-author comment-author">
								<?php
								$author = '<span>' . get_comment_author() . '</span>';
								$link = get_comment_author_url();
								if ( !empty($link) ) {
									$author = '<a href="' . esc_url($link) . '">' . $author . '</a>';
								}
								echo sprintf( '%s', $author );
								?>
							</h6>

							<div class="comment-info">
							<?php echo sprintf( '<time datetime="%s" class="ys-comment-date comment-date">%s</time>', get_comment_date('c') , get_comment_date(get_option('date_format')) ); ?>

							<?php edit_comment_link(' ' . esc_html__('Edit', 'jogasana'),'  ','') ?>

							<?php
							echo get_comment_reply_link(array_merge(
								array( 'reply_text' => esc_html__('Reply', 'jogasana') ),
								array( 'depth' => $depth, 'max_depth' => $args['max_depth'] )
							));
							?>
							</div>

						</header>
						
						<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'jogasana' ); ?></p>
						<?php endif; ?>

						<div class="comment-content">
							<?php comment_text(); ?>
						</div>

					</div>
					
			</article>

		<?php
	}
}
