<?php

/*  Base Function Class
/* ---------------------------------------------------------------------- */

if (!class_exists('Jogasana_Base')) {

	class Jogasana_Base {

		public $action_search = 'jogasana_action_search';
		public $action_post_share = 'jogasana_action_post_share';
		public $paths = array();
		public $directory_uri;
		private static $_instance;
		protected $used_fonts = array();
		protected $fontlist = array();

		/* 	Instance
		/* ---------------------------------------------------------------------- */

		public static function getInstance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

		function __construct() {

			$this->directory_uri = get_theme_file_uri('css');

			add_action( 'template_redirect', array($this, 'predefined_config'), 1 );
			add_action( 'admin_enqueue_scripts', array( &$this, 'admin_enqueue_styles_scripts' ), 100 );
			add_action( 'wp_enqueue_scripts', array( &$this, 'enqueue_styles_scripts' ) );
			add_filter( 'body_class', array(&$this, 'body_class'), 5 );
			
			add_action('wp_ajax_' . $this->action_post_share, array($this, 'ajax_post_share'));
			add_action('wp_ajax_nopriv_' . $this->action_post_share, array($this, 'ajax_post_share'));

			new jogasana_admin_user_profile();

			/*  Load Textdomain
			/* --------------------------------------------- */
			$this->load_textdomain();
		}
		
		
		/* 	Share Btn
		/* ---------------------------------------------------------------------- */
		
		public function ajax_post_share() {
			check_ajax_referer($this->action_post_share);

			$post_id = $_REQUEST['post_id'];
			$image = esc_url(wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ));
			$permalink = esc_url(get_the_permalink( $post_id ));
			$title = esc_attr(get_the_title( $post_id ));
			$extra_attr = 'target="_blank"';

			?>
			<div id="share_popup_holder">
				<div class="mad_popup">

					<span class="ys-title"><?php esc_html_e('Share', 'jogasana') ?>:</span>

					<div class="social_icon_list">
					<ul class="ys-social-icons social-icons">

							<li class="odnoklassniki-icon"><a href="http://www.odnoklassniki.ru/dk?st.cmd=addShare&st.s=1&st.comments=<?php echo urlencode($title) ?>&st._surl=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Odnoklassniki', 'jogasana') ?>"><i class="icon-odnoklassniki"></i></a></li>
							
							<li class="vk-icon"><a href="https://vk.com/share.php?url=<?php echo esc_url($permalink) ?>&amp;title=<?php echo urlencode($title) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Vkontakte', 'jogasana') ?>"><i class="icon-vkontakte"></i></a></li>
							
							<li class="linkedin-icon"><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo esc_url($permalink) ?>&amp;title=<?php echo urlencode($title) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('LinkedIn', 'jogasana') ?>"><i class="icon-linkedin"></i></a></li>
						
							<li class="tumblr-icon"><a href="http://www.tumblr.com/share/link?url=<?php echo esc_url($permalink) ?>&amp;name=<?php echo urlencode($title) ?>&amp;description=<?php echo urlencode(get_the_excerpt()) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Tumblr', 'jogasana') ?>"><i class="icon-tumblr"></i></a></li>
						
							<li class="tweet-icon"><a href="https://twitter.com/intent/tweet?text=<?php echo urlencode($title) ?>&amp;url=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Twitter', 'jogasana') ?>"><i class="icon-twitter"></i></a></li>
						
							<li class="fb-icon"><a href="https://www.facebook.com/sharer/sharer.php?u<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Facebook', 'jogasana') ?>"><i class="icon-facebook"></i></a></li>
						
							<li class="google-icon"><a href="https://plus.google.com/share?url=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?> title="<?php echo esc_attr__('Google +', 'jogasana') ?>"><i class="icon-gplus"></i></a></li>
						
					</ul>
					</div>

				</div>
			</div>
			
			<?php wp_die();
		}

		public function post_share_btn($post_id, $share_title='') {
			?>
			
			<a href="javascript:void(0)" data-post-id="<?php echo esc_attr($post_id); ?>" data-modal-action="<?php echo esc_attr($this->action_post_share) ?>" data-modal-nonce="<?php echo esc_attr(wp_create_nonce($this->action_post_share)) ?>" class="entry-icon post-share-button entry-share">
			
			<?php if($share_title != '') { ?>
			<span><?php echo esc_html($share_title); ?></span>
			<?php } ?>
			
			<i class="licon-share"></i></a>
		
			<?php
		}
		
		/* 	Initialization
		/* ---------------------------------------------------------------------- */

		function body_class($classes) {
			global $jogasana_config, $jogasana_settings;

			if ( isset($jogasana_config['header_type']) ) {
				$classes[] = 'ys-header-' . str_replace('ys-', '', $jogasana_config['header_type']);
			}
			if ( isset($jogasana_settings['show-loading-overlay']) ) {
				$classes[] = 'loading-overlay-'. $jogasana_settings['show-loading-overlay'];
			}

			return $classes;
		}

		public function admin_enqueue_styles_scripts() {
			$this->admin_enqueue_styles();
			$this->admin_enqueue_scripts();
		}

		public function enqueue_styles_scripts() {

			global $jogasana_settings;
			
			$protocol = is_ssl() ? 'https:' : 'http:';
			/* Vendor CSS */
			wp_enqueue_style( 'jquery-fancybox', trailingslashit(get_template_directory_uri()).'js/fancybox/jquery.fancybox.css', array(), null );
			wp_enqueue_style( 'owl-carousel', trailingslashit(get_template_directory_uri()).'js/owlcarousel/owl.carousel.css', array(), null );
			wp_enqueue_style( 'jquery-arcticmodal', trailingslashit(get_template_directory_uri()).'css/jquery.arcticmodal-0.3.css', array(), null );
			wp_enqueue_style( 'fontello', trailingslashit(get_template_directory_uri()).'css/fontello.css', array(), null );
			wp_enqueue_style( 'bootstrap-grid', trailingslashit(get_template_directory_uri()).'css/bootstrap-grid.min.css', array(), null );
			wp_register_style( 'audioplayer', trailingslashit(get_template_directory_uri()).'css/audioplayer.css', array(), null );
			
			/* Theme CSS */
			wp_enqueue_style( 'jogasana-demo', trailingslashit(get_template_directory_uri()).'fonts/demo-files/demo.css', array(), null );
			wp_enqueue_style( 'jogasana-styles-icon-custom', trailingslashit(get_template_directory_uri()).'fonts/styles_icon_custom.css', array(), null );
			wp_enqueue_style( 'jogasana-style', get_stylesheet_uri(), array(), null );

			// Skin Styles
			wp_deregister_style( 'jogasana-skin' );
			$prefix_name = 'skin_' . jogasana_get_blog_id() . '.css';
			$wp_upload_dir = wp_upload_dir();
			$stylesheet_dynamic_dir = $wp_upload_dir['basedir'] . '/dynamic_jogasana_dir';
			$stylesheet_dynamic_dir = str_replace('\\', '/', $stylesheet_dynamic_dir);
			$filename = trailingslashit($stylesheet_dynamic_dir) . $prefix_name;
			
			$version = get_option( 'jogasana_stylesheet_version' . $prefix_name );
			if ( empty($version) ) $version = '1';

			$demo = get_option( 'jogasana_demo' );
			if ( empty($demo) ) $demo = 'wbc-import-1';
			
			if ( file_exists($filename) ) {
				if ( is_ssl() ) {
					$wp_upload_dir['baseurl'] = str_replace("http://", "https://", $wp_upload_dir['baseurl']);
				}
				wp_register_style( 'jogasana-skin', $wp_upload_dir['baseurl'] . '/dynamic_jogasana_dir/' . $prefix_name, null, $version );
			} 
			wp_enqueue_style( 'jogasana-skin' );
			wp_enqueue_style( 'jogasana-layout', trailingslashit(get_template_directory_uri()).'css/responsive.css', array(), null );
			wp_enqueue_style( 'jogasana-custom-style', trailingslashit(get_template_directory_uri()).'css/custom_style.css', array(), null );

			if ( is_rtl() ) {
				wp_enqueue_style( 'jogasana-rtl',  trailingslashit(get_template_directory_uri()).'css/rtl.css', array( 'jogasana-style', 'jogasana-skin' ), '1', 'all' );
			}
			
			// Load Google Fonts
			$google_fonts = array();
			$fonts = array( 'body', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'menu', 'sub-menu' );
			foreach ( $fonts as $option ) {
				if ( isset($jogasana_settings[$option.'-font']['google']) && $jogasana_settings[$option.'-font']['google'] !== 'false' ) {
					$font = $jogasana_settings[$option.'-font']['font-family'];
					if ( !in_array($font, $google_fonts) ) {
						$google_fonts[] = $font;
					}
				}
			}

			$font_family = array();
			foreach ( $google_fonts as $font ) {
				
				/*
				Translators: If there are characters in your language that are not supported
				by chosen font(s), translate this to 'off'. Do not translate into your own language.
				 */
				$f = sprintf( _x( 'on', '%s font: on or off', 'jogasana' ), $font );
				if ( 'off' !== $f ) {
				$font_family[] .= $font . ':300,300italic,400,400italic,500,600,600italic,700,700italic,800,800italic%7C,900,900italic';
				}
			}

			if ( $font_family ) {
				$charsets = '';

				if ( isset($jogasana_settings['select-google-charset']) && $jogasana_settings['select-google-charset'] && isset($jogasana_settings['google-charsets']) && $jogasana_settings['google-charsets']) {
					$i = 0;
					foreach ( $jogasana_settings['google-charsets'] as $charset ) {
						if ( $i == 0 ) {
							$charsets .= $charset;
						} else {
							$charsets .= ",".$charset;
						}
						$i++;
					}
				}

				$fonts_url = add_query_arg( array(
					'family' => urlencode( implode('|', $font_family) ),
					'subset' => urlencode( $charsets )
				), '//fonts.googleapis.com/css' );

				wp_enqueue_style( 'jogasana-google-fonts', $fonts_url, array(), null );
			}

			// Enqueue scripts
			
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}

			$scripts_deps = array('jquery');
			
			wp_deregister_script( 'isp_googlemaps' );
			wp_dequeue_script( 'isp_googlemaps' );
			
			
			/* Include Libs & Plugins */
			wp_register_script( 'audioplayer', trailingslashit(get_template_directory_uri()).'js/audioplayer.js', array('jquery'), '', true);
			wp_register_script( 'jquery-countdown-plugin', trailingslashit(get_template_directory_uri()).'js/jquery.countdown.plugin.min.js', array('jquery'), '', true );
			wp_register_script( 'jquery-countdown', trailingslashit(get_template_directory_uri()).'js/jquery.countdown.min.js', array('jquery'), '', true );			
			
			wp_enqueue_script( 'modernizr', trailingslashit(get_template_directory_uri()).'js/libs/jquery.modernizr.js' );
			wp_enqueue_script( 'jquery-queryloader2', trailingslashit(get_template_directory_uri()).'js/jquery.queryloader2.min.js', array('jquery'), '', true );
			wp_enqueue_script( 'instafeed', trailingslashit(get_template_directory_uri()).'js/instafeed.min.js', array('jquery'), '', true );
			wp_enqueue_script( 'jquery-ui-core' );
			wp_enqueue_script( 'jquery-ui-tabs' );
			wp_enqueue_script('jquery-form');
			wp_enqueue_script( 'jquery-arcticmodal', trailingslashit(get_template_directory_uri()).'js/jquery.arcticmodal-0.3.min.js', array('jquery'), '', true);
			wp_enqueue_script( 'jquery-fancybox', trailingslashit(get_template_directory_uri()).'js/fancybox/jquery.fancybox.min.js', array('jquery'), '', true);
			wp_enqueue_script( 'owl-carousel', trailingslashit(get_template_directory_uri()).'js/owlcarousel/owl.carousel.min.js', array('jquery'), '', true );
			wp_enqueue_script( 'isotope', trailingslashit(get_template_directory_uri()).'js/isotope.pkgd.min.js', array('jquery'), '', true);
			wp_enqueue_script( 'jquery-scrollto', trailingslashit(get_template_directory_uri()).'js/jquery.scrollTo.min.js', array('jquery'), '', true );
			wp_enqueue_script( 'jquery-localscroll', trailingslashit(get_template_directory_uri()).'js/jquery.localScroll.min.js', array('jquery'), '', true );
			
			/* Theme files */
			wp_enqueue_script( 'jogasana-plugins', trailingslashit(get_template_directory_uri()).'js/jogasana.plugins' . ( WP_DEBUG ? '' : '' ) .'.js', array('jquery'), '', true );
			wp_enqueue_script( 'jogasana-core', trailingslashit(get_template_directory_uri()).'js/jogasana.core' . ( WP_DEBUG ? '' : '' ) .'.js', $scripts_deps, '', true );

			if ( isset($jogasana_settings['js-code-head']) && $jogasana_settings['js-code-head']) {
				wp_add_inline_script( 'jogasana-core', $jogasana_settings['js-code-head'] );
			}

			wp_localize_script('jogasana-core', 'jogasana_global_vars', array(
				'template_base_uri' => get_template_directory_uri() . '/',
				'icon_map_uri' => get_template_directory_uri() . '/config-composer/assets/images/marker.png',
				'site_url' => esc_url(get_home_url('/')),
				'loading_color' => esc_attr($jogasana_settings['loading-color']),
				'ajax_nonce' => wp_create_nonce('ajax-nonce'),
				'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
				'ajax_loader_url' => get_template_directory_uri() . '/images/ajax-loader.gif',
				'rtl' => is_rtl() ? 1 : 0
			));
			
			wp_localize_script('jogasana_popular-widget', 'jogasana_global_vars', array(
				'template_base_uri' => get_template_directory_uri() . '/',
				'icon_map_uri' => get_template_directory_uri() . '/config-composer/assets/images/marker.png',
				'site_url' => esc_url(get_home_url('/')),
				'loading_color' => esc_attr($jogasana_settings['loading-color']),
				'ajax_nonce' => wp_create_nonce('ajax-nonce'),
				'ajaxurl' => esc_url(admin_url('admin-ajax.php')),
				'ajax_loader_url' => get_template_directory_uri() . '/images/ajax-loader.gif',
				'rtl' => is_rtl() ? 1 : 0
			));

		}

		/* 	Enqueue Admin Styles
		/* ---------------------------------------------------------------------- */

		public function admin_enqueue_styles() {
			wp_enqueue_style( 'jogasana-admin', $this->directory_uri . '/admin.css', false);
			wp_enqueue_style( 'jogasana-styles-icon-custom', get_theme_file_uri('fonts/styles_icon_custom.css'), false);
		}

		/*  Enqueue Admin Scripts
		/* ---------------------------------------------------------------------- */

		public function admin_enqueue_scripts() {
			if ( function_exists('add_thickbox') ) {
				add_thickbox();
			}

			wp_enqueue_media();
			wp_enqueue_script( 'jogasana-admin', get_template_directory_uri() . '/js/admin.js' );
		}

		/* 	Load Textdomain
		/* ---------------------------------------------------------------------- */

		public function load_textdomain () {
			load_theme_textdomain( 'jogasana', get_template_directory()  . '/lang' );
		}

		/*	Check page wrapper
		/* ---------------------------------------------------------------------- */

		public function check_page_wrapper() {
			global $jogasana_config, $jogasana_settings;

			$post_id = jogasana_post_id();

			$page_wrapper = $jogasana_settings['wrapper'];
			$post_meta_page_wrapper = trim(get_post_meta( $post_id, 'jogasana_wrapper', true ));

			if ( $post_meta_page_wrapper ) {
				$page_wrapper = $post_meta_page_wrapper;
			}

			if ( !$page_wrapper ) {
				$page_wrapper = 'ys-wide-layout-type';
			}

			$jogasana_config['page_wrapper'] = $page_wrapper;
		}

		/*	Check page layout
		/* ---------------------------------------------------------------------- */

		public function check_page_layout () {
			global $jogasana_config, $jogasana_settings;

			$result = false;
			$sidebar_position = 'page-layout';

		$post_id = jogasana_post_id();
		$custom_sidebar = $jogasana_settings['sidebar'];
		if ( is_singular(array('post')) ) {
			$custom_sidebar = $jogasana_settings['single-post-sidebar'];
		}
		if ( is_archive() ) {
			$custom_sidebar = $jogasana_settings['archive-post-sidebar'];
		}

		if ( is_post_type_archive('challenge') || is_tax('challenges') ) {
			global $wp_query;
			$term =	$wp_query->queried_object;
			$term_id = $term->term_id;
			if(get_metadata('challenges', $term_id, 'sidebar', true)) {
			$custom_sidebar = get_metadata('challenges', $term_id, 'sidebar', true);
			}	
		}

		if (class_exists('WooCommerce')) {
			if ( JOGASANA_WOOCOMMERCE_CONFIG::is_realy_woocommerce_page() ) {
				$custom_sidebar = $jogasana_settings['product-sidebar'];
			}
		}

		$page_sidebar = trim(get_post_meta( $post_id, 'jogasana_page_sidebar', true ));

		if ( $page_sidebar ) {
			$custom_sidebar = $page_sidebar;
		}

		if ( is_singular(array('page', 'post')) && !empty($post_id) && $page_sidebar) {
			$custom_sidebar = $page_sidebar;
		}
		
		
			if ( is_page() || is_search() || is_attachment() ) { $sidebar_position = 'page-layout'; }

			if ( is_archive() ) { $sidebar_position = 'post-archive-layout'; }

			if ( is_single() ) { $sidebar_position = 'post-single-layout'; }

			if ( is_singular('mp-event') ) { $result = 'ys-no-sidebar'; }
			
			if ( is_singular() ) {
				$result = trim(get_post_meta( $post_id, 'jogasana_page_sidebar_position', true ));
			}

			if ( is_singular('portfolio') ) { $result = 'ys-no-sidebar'; }

			if ( is_404() || is_post_type_archive('tribe_events') || is_singular('tribe_events') ) { $result = 'ys-no-sidebar'; }

			if ( is_post_type_archive('testimonials') || is_singular('testimonials') || is_tax('testimonials_category') ) {
				$result = 'ys-no-sidebar';
			}
			if ( is_post_type_archive('team-members') || is_singular('team-members') || is_tax('team_category') ) {
				$result = 'ys-no-sidebar';
			}
			
			if ( is_post_type_archive('challenge') || is_tax('challenges') ) {
				global $wp_query;
				$term =	$wp_query->queried_object;
				$term_id = $term->term_id;
				$sidebar_cat = get_metadata('challenges', $term_id, 'sidebar_position', true);
				$result = 'ys-right-sidebar';
				if($sidebar_cat != '') {
					$result = $sidebar_cat;
				}
			}

			if ( class_exists('WooCommerce') ) {

				if ( JOGASANA_WOOCOMMERCE_CONFIG::is_realy_woocommerce_page() ) {

					if ( JOGASANA_WOOCOMMERCE_CONFIG::jogasana_is_shop() ) {
						$result_sidebar_position = trim(get_post_meta( $post_id, 'jogasana_page_sidebar_position', true ));
						if ( empty($result_sidebar_position) ) {
						$result = $jogasana_settings['product-archive-layout'];
						} else {
							$result = $result_sidebar_position;
						}
					} else {
						
						$result_sidebar_position = trim(get_post_meta( $post_id, 'jogasana_page_sidebar_position', true ));
						if ( empty($result_sidebar_position) ) {
						$result = $jogasana_settings['product-archive-layout'];
						} else {
							$result = $result_sidebar_position;
						}
						
					}
				}

				if ( JOGASANA_WOOCOMMERCE_CONFIG::jogasana_is_product() ) {
					$result_sidebar_position = trim(get_post_meta( $post_id, 'jogasana_page_sidebar_position', true ));

					if ( empty($result_sidebar_position) ) {
						$result = $jogasana_settings['product-single-layout'];
					} else {
						$result = $result_sidebar_position;
					}
				}

			}			

			if ( !$result ) {
				$result = $jogasana_settings[$sidebar_position];
			}

			if ( $result != 'ys-no-sidebar' && ( empty($custom_sidebar) || !is_active_sidebar($custom_sidebar) ) ) {
				$result = 'ys-no-sidebar';
			}

			if ( $result ) {
				$jogasana_config['sidebar_position'] = $result;
			}

		}

		public function check_header_classes() {
			global $jogasana_config, $jogasana_settings;

			$result = array();
			$post_id = jogasana_post_id();
			$header_position = '';
			
			$header_sticky = 'header-sticky-0';
			if ( !empty($jogasana_settings['header-sticky']) ) $header_sticky = 'sticky-header';
			
			$header_type = 'ys-type-1';
			if ( !empty($jogasana_settings['header-type']) ) $header_type = $jogasana_settings['header-type'];
			
			$post_meta_header_type = trim(get_post_meta( $post_id, 'jogasana_header_type', true ));
			
			if ( $post_meta_header_type ) {
				$header_type = $post_meta_header_type;
			}
			
			$post_meta_header_position = trim(get_post_meta( $post_id, 'jogasana_header_position', true ));
			if ( $post_meta_header_position ) {
				$header_position = $post_meta_header_position;
			}

			$result['header_type'] = $header_type;
			$result[] = $header_sticky;
			$result[] = $header_position;

			if ( $header_type ) {

				switch( $result['header_type'] ) {
					case 'ys-type-1':
						$result[] = 'header';
						$result[] = 'fixed-header';
						break;
					case 'ys-type-2':
						$result[] = 'header';
						$result[] = 'style-2';
						break;
					case 'ys-type-3':
						$result[] = 'header';
						$result[] = 'style-3';
						break;
					case 'ys-type-4':
						$result[] = 'header';
						$result[] = 'style-4';
						break;	
					case 'ys-type-5':
						$result[] = 'header';
						$result[] = 'style-4';
						$result[] = 'var2';
						break;	
					case 'ys-type-6':
						$result[] = 'header';
						break;		
				}
			}

			$jogasana_config['header_classes'] = implode( ' ', array_values($result) );
			$jogasana_config['header_type'] = $result['header_type'];
		}

		public function check_footer_classes() {
			global $jogasana_config, $jogasana_settings;
			$classes = array();
			$post_id = jogasana_post_id();
			$footer_bg_color = get_post_meta( jogasana_post_id(), 'jogasana_footer_bg_color', true );

			if ( !empty($footer_bg_color) ) {
				$classes[] = 'ys-has-bg-color';
			}

			$footer_type = 'footer-1';
			if( !empty($jogasana_settings['footer-type']) ) {
			$footer_type = $jogasana_settings['footer-type'];
			}
			$post_meta_footer_type = trim(get_post_meta( $post_id, 'jogasana_footer_type', true ));
			
			if ( $post_meta_footer_type ) {
				$footer_type = $post_meta_footer_type;
			}

			if ( !empty($footer_type) ) {
				
				switch( $footer_type ) {
					case 'footer-1':
						$classes[] = '';
						break;
					case 'footer-2':
						$classes[] = 'style-2';
						break;	
					case 'footer-3':
						$classes[] = 'style-3';
						break;
					case 'footer-4':
						$classes[] = 'style-4';
						break;		
				}
				
				$classes[] = $footer_type;
			}
			
			$jogasana_config['footer_classes'] = implode( ' ', array_values($classes) );
			$jogasana_config['footer_type'] = $footer_type;
		}

		public function check_page_content_classes() {
			global $jogasana_config;

			$result = array();
			$result[] = 'ys-page-content-wrap';
			$result[] = 'page-content-wrap';
			$result[] = $jogasana_config['sidebar_position'];

			$jogasana_config['page_content_classes'] = implode( ' ', array_filter(array_values($result)) );
		}

		public function predefined_config() {
			$this->check_page_wrapper();
			$this->check_header_classes();
			$this->check_page_layout();
			$this->check_page_content_classes();
			$this->check_footer_classes();
		}

		/* 	Instance
		/* ---------------------------------------------------------------------- */

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}

			return self::$_instance;
		}

	}

	if ( ! function_exists('jogasana_base') ) {

		function jogasana_base() {
			// Load required classes and functions
			return Jogasana_Base::getInstance();
		}

		jogasana_base();

	}


}