<?php

if (!class_exists('Jogasana_Hooks')) {

	class Jogasana_Hooks {

		function __construct() {
			add_action('init', array($this, 'init'));
		}

		public function init() {
			$this->add_hooks();
		}

		public function add_hooks() {

			global $jogasana_settings;

			add_action('jogasana_header_layout', array(&$this, 'template_header_layout_hook'));

			if ( $jogasana_settings['show-loading-overlay'] ) {
				add_action('jogasana_body_append', array( &$this, 'preloader' ));
			}

			add_action( 'jogasana_header_after', array( &$this, 'header_after_hook' ) );
			add_action( 'jogasana_before_footer', array( $this, 'template_footer_newsletter' ), 9 );
			add_action( 'jogasana_footer_in_top_part', array( &$this, 'template_footer' ) );
		}

		public function template_footer_newsletter() {
			get_template_part( 'template-parts/footer', 'newsletter' );
		}
		
		public function template_header_layout_hook($type) {
			get_template_part( 'template-parts/header', $type );
		}

		public function template_footer() {
			get_template_part( 'template-parts/footer', 'widgets' );
		}
		
		public function header_after_hook() {
			$this->page_title_and_breadcrumbs();
		}

		public function preloader() { ?><div class="loader ys-preloader"></div><?php }

		public function page_title_and_breadcrumbs() {

			global $jogasana_settings;
			$post_id = jogasana_post_id();
			$mode = 'default';
			if(!empty(get_post_meta( $post_id, 'jogasana_page_title_style', true ))) {
			$mode = get_post_meta( $post_id, 'jogasana_page_title_style', true );
			}
			
			if( class_exists('WooCommerce') ) {
				if ( JOGASANA_WOOCOMMERCE_CONFIG::is_realy_woocommerce_page() ) {
					if ( $post_id && get_post_meta( $post_id, 'jogasana_page_title_style', true ) ) {
						$mode    = get_post_meta( $post_id, 'jogasana_page_title_style', true );
						} else {
						$mode = 'shop-default';
						}
				}
			}
			
			switch ( $mode ) {
				
				case 'shop-default':
					$breadcrumb = $jogasana_settings['shop-show-breadcrumbs'];
					$page_title_show = $jogasana_settings['shop-show-pagetitle'];
					$page_title_align = $jogasana_settings['shop-align-breadcrumbs'];
					$breadcrumbs_bg_color = $jogasana_settings['shop-breadcrumbs-bg']['background-color'];
					$breadcrumbs_bg_image = str_replace(array('http://', 'https://'), array('//', '//'), $jogasana_settings['shop-breadcrumbs-bg']['background-image']);
					$breadcrumbs_bg_repeat = $jogasana_settings['shop-breadcrumbs-bg']['background-repeat'];
					$breadcrumbs_bg_size = $jogasana_settings['shop-breadcrumbs-bg']['background-size'];
					$breadcrumbs_bg_attachment = $jogasana_settings['shop-breadcrumbs-bg']['background-attachment'];
					$breadcrumbs_bg_position = $jogasana_settings['shop-breadcrumbs-bg']['background-position'];
				break;
				
				case 'default':
					$breadcrumb = $jogasana_settings['show-breadcrumbs'];
					$page_title_align = $jogasana_settings['align-breadcrumbs'];
					$page_title_show = $jogasana_settings['show-pagetitle'];
					
					$breadcrumbs_bg_color = $jogasana_settings['breadcrumbs-bg']['background-color'];
					$breadcrumbs_bg_image = str_replace(array('http://', 'https://'), array('//', '//'), $jogasana_settings['breadcrumbs-bg']['background-image']);
					$breadcrumbs_bg_repeat = $jogasana_settings['breadcrumbs-bg']['background-repeat'];
					$breadcrumbs_bg_size = $jogasana_settings['breadcrumbs-bg']['background-size'];
					$breadcrumbs_bg_attachment = $jogasana_settings['breadcrumbs-bg']['background-attachment'];
					$breadcrumbs_bg_position = $jogasana_settings['breadcrumbs-bg']['background-position'];
				break;
				case 'custom':
					$breadcrumb = get_post_meta( $post_id, 'jogasana_hide_breadcrumb', true );
					$page_title_align = get_post_meta( $post_id, 'jogasana_page_title_align', true );
					$page_title_show = get_post_meta( $post_id, 'jogasana_hide_breadcrumb_title', true );
					
					$breadcrumbs_bg_color = get_post_meta( $post_id, 'jogasana_page_title_bg_color1', true );
					$breadcrumbs_bg_image = get_post_meta( $post_id, 'jogasana_page_title_bg_image', true );

					if ( !empty($breadcrumbs_bg_image) && $breadcrumbs_bg_image != '' ) {
						if ( isset($breadcrumbs_bg_image) ) {
							$breadcrumbs_bg_image = wp_get_attachment_image_src($breadcrumbs_bg_image, '');

							if ( is_array($breadcrumbs_bg_image) && isset($breadcrumbs_bg_image[0]) ) {
								$breadcrumbs_bg_image = $breadcrumbs_bg_image[0];
							}

						}
					} else{
						$breadcrumbs_bg_image = '';
					}
					
					
					$breadcrumbs_bg_repeat = get_post_meta( $post_id, 'jogasana_page_title_bg_image_repeat', true );
					$breadcrumbs_bg_size = '';
					$breadcrumbs_bg_attachment = '';
					$breadcrumbs_bg_position = get_post_meta( $post_id, 'jogasana_page_title_bg_image_position', true );
				break;
				default:
					$breadcrumb = true;
					$page_title_show = true;
					$page_title_align = 'center';
					$breadcrumbs_bg_color = '';
					$breadcrumbs_bg_image = '';
					$breadcrumbs_bg_repeat = '';
					$breadcrumbs_bg_size = '';
					$breadcrumbs_bg_attachment = '';
					$breadcrumbs_bg_position = '';
					
				break;
			}

			if ( $mode == 'none' || is_front_page() || is_404() ) return; 
			
			if ( is_search() ) {
				$page_title_align = 'center';
				$breadcrumb = false;
				$page_title_show = true;
			}
			
			?>

			<?php 
            $css_bg = array();
			if (!empty( $page_title_align )) { $css_bg[] = "text-align: $page_title_align;"; }
			
			if (!empty( $breadcrumbs_bg_image ) && $breadcrumbs_bg_image != 'none') 			 { $css_bg[] = "background-image: url('$breadcrumbs_bg_image');"; }
			if (!empty( $breadcrumbs_bg_image ) && !empty( $breadcrumbs_bg_attachment )) { $css_bg[] = "background-attachment: $breadcrumbs_bg_attachment;"; }
			if (!empty( $breadcrumbs_bg_image ) && !empty( $breadcrumbs_bg_position ))   { $css_bg[] = "background-position: $breadcrumbs_bg_position;"; }
			if (!empty( $breadcrumbs_bg_image ) && !empty( $breadcrumbs_bg_repeat ))     { $css_bg[] = "background-repeat: $breadcrumbs_bg_repeat;"; }
			if (!empty( $breadcrumbs_bg_image ) && !empty( $breadcrumbs_bg_size ))     { $css_bg[] = "background-size: $breadcrumbs_bg_size;"; }
			
			if (!empty( $breadcrumbs_bg_color )) { 
			$css_bg[] = "background-color: $breadcrumbs_bg_color !important;"; 
			}
            ?>

			<div class="breadcrumbs-wrap title-<?php echo esc_attr($page_title_align); ?> show-title-<?php echo esc_attr($page_title_show); ?>" style=" <?php echo implode( ' ', $css_bg ); ?>">

			<div class="container">
			
				<?php if ( is_page() ): ?>

					<?php if ( $page_title_show ): ?>
						<?php echo jogasana_title(); ?>
					<?php endif; ?>

					<?php if ( $breadcrumb ): ?>

						<ul class="ys-breadcrumbs breadcrumbs">
							<?php echo jogasana_breadcrumbs(array(
								'separator' => ''
							)); ?>
						</ul>

					<?php endif; ?>

				<?php elseif ( is_single() ): ?>

					<?php if ( $page_title_show ): ?>
					<?php echo jogasana_title(array( 'heading' => 'h1' )); ?>
					<?php endif; ?>

						<?php if ( $breadcrumb ): ?>

						<ul class="ys-breadcrumbs breadcrumbs">
							<?php echo jogasana_breadcrumbs(array(
								'separator' => ''
							)); ?>
						</ul>

						<?php endif; ?>

				<?php elseif ( is_search() ): global $wp_query; ?>

					<?php if ( !empty($wp_query->found_posts) ): ?>

						<?php if ($wp_query->found_posts > 1): ?>

							<?php
							echo jogasana_title(
								array(
									'title' => esc_html__('Search results:', 'jogasana')." " . esc_attr(get_search_query()) . " (". $wp_query->found_posts .")"
								)
							); ?>

						<?php else: ?>

							<?php
							echo jogasana_title(
								array(
									'title' => esc_html__('Search result:', 'jogasana')." " . get_search_query() . " (". $wp_query->found_posts .")"
								)
							); ?>

						<?php endif; ?>

					<?php else: ?>

						<?php if ( !empty($_GET['s']) ): ?>

							<?php
							echo jogasana_title(
								array(
									'title' => esc_html__('Search results:', 'jogasana') . " " . get_search_query()
								)
							); ?>

						<?php else: ?>

							<?php
							echo jogasana_title(
								array(
									'title' => esc_html__('To search the site please enter a valid term', 'jogasana')
								)
							); ?>

						<?php endif; ?>

					<?php endif; ?>

				<?php else: ?>

					<?php if ( is_archive() && is_post_type_archive('tribe_events') ): ?>

						<?php
							echo jogasana_title(
								array(
									'title' => $jogasana_settings['events-title']
								)
							); ?>

						<?php if ( $breadcrumb ): ?>

						<ul class="ys-breadcrumbs events_breadcrumbs breadcrumbs">
							<?php echo jogasana_breadcrumbs(array(
								'separator' => ''
							)); ?>
						</ul>

						<?php endif; ?>
						
					<?php elseif ( is_archive() || is_front_page() ): ?>

						<?php if ( $page_title_show ): ?>
						<?php
							echo jogasana_title(
								array(
									'title' => get_the_archive_title()
								)
							); ?>
						<?php endif; ?>	

						<?php if ( $breadcrumb ): ?>

						<ul class="ys-breadcrumbs archive_breadcrumbs breadcrumbs">
							<?php echo jogasana_breadcrumbs(array(
								'separator' => ''
							)); ?>
						</ul>

						<?php endif; ?>

					<?php else: ?>

						<?php
						echo jogasana_title(
							array(
								'title' => get_the_archive_title()
							)
						); ?>

					<?php endif; ?>

				<?php endif; ?>

			</div></div>
			<?php
		}

		/* 	Get Cookie
		/* ---------------------------------------------------------------------- */

		public static function getcookie( $name ) {
			if ( isset( $_COOKIE[$name] ) )
				return maybe_unserialize( stripslashes( $_COOKIE[$name] ) );

			return array();
		}

	}

	new Jogasana_Hooks();
}
