<?php
/**
 * Single Event Template
 * A single event. This displays the event title, description, meta, and
 * optionally, the Google map for the event.
 *
 * Override this template in your own theme by creating a file at [your-theme]/tribe-events/single-event.php
 *
 * @package TribeEventsCalendar
 * @version 4.6.19
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

$events_label_singular = tribe_get_event_label_singular();
$events_label_plural   = tribe_get_event_label_plural();

$event_id = get_the_ID();

?>

<div id="tribe-events-content" class="tribe-events-single">

	<div class="content-element4">
	<div class="page-nav">
	
		<div class="tribe-events-back flex-item">
			<a class="info-btn prev-btn" href="<?php echo esc_url( tribe_get_events_link() ); ?>"> <?php printf( esc_html_x( 'All %s', '%s Events plural label', 'jogasana' ), $events_label_plural ); ?></a>
		</div>
		
		<div class="flex-item">
        <div class="btn-wrap">
		
		<?php do_action( 'tribe_events_single_event_after_the_content' ) ?>
		
		</div>
		</div>
	
	</div>
	</div>

	<!-- Notices -->
	<?php tribe_the_notices() ?>

	<?php the_title( '<h1 class="tribe-events-single-event-title">', '</h1>' ); ?>

	<div class="tribe-events-schedule tribe-clearfix">
	
		<i class="licon-clock3"></i>
		<div class="wrapper">
		<?php echo tribe_events_event_schedule_details( $event_id ); ?>

		<?php if ( tribe_get_cost() ) : ?>
			<span class="tribe-events-cost product-price"><?php echo tribe_get_cost( null, true ) ?></span>
		<?php endif; ?>
		</div>
		
	</div>

	<!-- Event header -->
	<div id="tribe-events-header" <?php tribe_events_the_header_attributes() ?>>
		<!-- Navigation -->
		<h3 class="tribe-events-visuallyhidden"><?php printf( esc_html__( '%s Navigation', 'jogasana' ), $events_label_singular ); ?></h3>
		<ul class="tribe-events-sub-nav">
			<li class="tribe-events-nav-previous"><?php tribe_the_prev_event_link( '<span>&laquo;</span> %title%' ) ?></li>
			<li class="tribe-events-nav-next"><?php tribe_the_next_event_link( '%title% <span>&raquo;</span>' ) ?></li>
		</ul>
		<!-- .tribe-events-sub-nav -->
	</div>
	<!-- #tribe-events-header -->

	<?php while ( have_posts() ) :  the_post(); ?>
		<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
			
			<div class="content-element2">
            <div class="row">
			
				<div class="col-lg-8 col-md-12">
				<!-- Event featured image, but exclude link -->
				<?php echo tribe_event_featured_image( $event_id, 'large', false ); ?>
				</div>
				
				<div class="col-lg-4 col-md-12">
				<?php 
				echo '<div class="tribe-events-meta-group tribe-events-meta-group-gmap">';
				tribe_get_template_part( 'modules/meta/map' );
				echo '</div>';
				?>
				</div>
				
			</div>
			</div>

			<!-- Event content -->
			<?php do_action( 'tribe_events_single_event_before_the_content' ) ?>
			<div class="tribe-events-single-event-description tribe-events-content">
				<?php the_content(); ?>
			</div>
			<!-- .tribe-events-single-event-description -->
			

			<!-- Event meta -->
			<?php do_action( 'tribe_events_single_event_before_the_meta' ) ?>
			<?php tribe_get_template_part( 'modules/meta' ); ?>
			<?php do_action( 'tribe_events_single_event_after_the_meta' ) ?>
		</div> <!-- #post-x -->
		<?php if ( get_post_type() == Tribe__Events__Main::POSTTYPE && tribe_get_option( 'showComments', false ) ) comments_template() ?>
	<?php endwhile; 
	
	$post_id = get_the_ID();
	$image = esc_url(wp_get_attachment_url( get_post_thumbnail_id( $post_id ) ));
	$permalink = esc_url( apply_filters('the_permalink', get_the_permalink( $post_id )) );
	$title = esc_attr(get_the_title( $post_id ));
	$extra_attr = 'target="_blank"';
	?>

	<div class="share-wrap">
		<span class="share-title"><?php echo esc_html__('Share this:', 'jogasana') ?></span>
			<ul class="social-icons share  ls-none">

				<li><a class="sh-facebook" href="https://www.facebook.com/sharer/sharer.php?u<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-facebook"></i></a></li>
			
				<li><a class="sh-twitter" href="https://twitter.com/intent/tweet?text=<?php echo urlencode(esc_attr($title)) ?>&amp;url=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-twitter"></i></a></li>
			
				
				<li><a class="sh-pinterest" href="https://pinterest.com/pin/create/button/?url=<?php echo esc_url($permalink) ?>&amp;media=<?php echo esc_url($image) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-pinterest"></i></a></li>
			
				<li><a class="sh-mail" href="mailto:?subject=<?php echo urlencode(esc_attr($title)) ?>&amp;body=<?php echo esc_url($permalink) ?>" <?php echo wp_kses_post($extra_attr) ?>><i class="icon-mail"></i></a></li>
				
			</ul>
	</div>
	
	
	<!-- Event footer -->
	<div id="tribe-events-footer">
		<!-- Navigation -->
		<h3 class="tribe-events-visuallyhidden"><?php printf( esc_html__( '%s Navigation', 'jogasana' ), $events_label_singular ); ?></h3>
		<ul class="tribe-events-sub-nav">
			<li class="tribe-events-nav-previous">
			<?php if( tribe_get_prev_event_link() ) { ?>
			<a href="<?php echo esc_url(tribe_get_prev_event_link()) ?>" class="link-text"><?php echo esc_html__( 'Previous Event', 'jogasana' ) ?></a>
			<h6><?php tribe_the_prev_event_link( '%title%' ) ?></h6>
			<?php } ?>
			</li>
			<li class="tribe-events-nav-next">
			<?php if( tribe_get_next_event_link() ) { ?>
			<a href="<?php echo esc_url(tribe_get_next_event_link()) ?>" class="link-text"><?php echo esc_html__( 'Next Event', 'jogasana' ) ?></a>
			<h6><?php tribe_the_next_event_link( '%title%' ) ?></h6>
			<?php } ?>
			</li>
		</ul>
		<!-- .tribe-events-sub-nav -->
	</div>
	<!-- #tribe-events-footer -->

</div><!-- #tribe-events-content -->


<div class="section_related_events">
				
	<div class="related-events">
		
		<h4><?php _e( 'Related Events', 'jogasana' ) ?></h4>
		
		<div class="welcome-section blog-type fx-col-3">
		<?php 
		$esclude_post  = get_the_ID();
		$category = jogasana_get_events_category($esclude_post);
		
		jogasana_the_related_events(3, $category, $esclude_post, 'isotope three-collumn clearfix entry-box'); 
		?>
		</div>

	</div>
				
</div>
