<?php
/**
 * Events List Widget Template
 * This is the template for the output of the events list widget.
 * All the items are turned on and off through the widget admin.
 * There is currently no default styling, which is needed.
 *
 * This view contains the filters required to create an effective events list widget view.
 *
 * You can recreate an ENTIRELY new events list widget view by doing a template override,
 * and placing a list-widget.php file in a tribe-events/widgets/ directory
 * within your theme directory, which will override the /views/widgets/list-widget.php.
 *
 * You can use any or all filters included in this file or create your own filters in
 * your functions.php. In order to modify or extend a single filter, please see our
 * readme on templates hooks and filters (TO-DO)
 *
 * @version 4.5.13
 * @return string
 *
 * @package TribeEventsCalendar
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

$events_label_plural = tribe_get_event_label_plural();
$events_label_plural_lowercase = tribe_get_event_label_plural_lowercase();

$posts = tribe_get_list_widget_events();

// Check if any event posts are found.
if ( $posts ) : ?>

	<div class="event-box tribe-list-widget">
		<?php
		// Setup the post data for each event.
		foreach ( $posts as $post ) :
			setup_postdata( $post );
			
			$venue_details = tribe_get_venue_details();
			// Venue
			$has_venue_address = ( ! empty( $venue_details['address'] ) ) ? ' location' : '';

			// Organizer
			$organizer = tribe_get_organizer();
			
			$start_date = tribe_get_start_date( null, false, 'd' );
			$start_date_month = tribe_get_start_date( null, false, 'M' );
			?>
			<div class="entry <?php tribe_events_event_classes() ?>">
				<div class="event-date"><?php echo esc_html( $start_date_month ) ?><span><?php echo esc_html( $start_date ) ?></span></div>
				
				<div class="entry-body">
				
					<?php do_action( 'tribe_events_list_widget_before_the_event_title' ); ?>
					<!-- Event Title -->
					<h6 class="tribe-event-title entry-title">
						<a href="<?php echo esc_url( tribe_get_event_link() ); ?>" rel="bookmark"><?php the_title(); ?></a>
					</h6>

					<?php do_action( 'tribe_events_list_widget_after_the_event_title' ); ?>
					
					<?php do_action( 'tribe_events_list_widget_before_the_meta' ) ?>

					<div class="our-info vr-type">
                      
                      <div class="info-item">
                        <i class="licon-clock3"></i>
                        <div class="wrapper">
                          <span><?php echo tribe_events_event_schedule_details(); ?></span>
                        </div>
                      </div>
					  
					  <?php if ( $venue_details ) { ?>
                      <div class="info-item">
                        <i class="licon-map-marker"></i>
                        <div class="wrapper">
                          <span>
						  <?php
								$address_delimiter = empty( $venue_address ) ? ' ' : ', ';
								echo implode( $address_delimiter, $venue_details );
							?>
						  </span>
                        </div>
                      </div>
					  <?php } ?>
                    
                    </div>

					<?php do_action( 'tribe_events_list_widget_after_the_meta' ) ?>
				
				</div>
			</div>
		<?php
		endforeach;
		?>
	</div>

	<p class="tribe-events-widget-link">
		<a class="btn btn-small btn-style-4" href="<?php echo esc_url( tribe_get_events_link() ); ?>" rel="bookmark"><?php printf( esc_html__( 'More %s', 'jogasana' ), $events_label_plural ); ?></a>
	</p>

<?php
// No events were found.
else : ?>
	<p><?php printf( esc_html__( 'There are no upcoming %s at this time.', 'jogasana' ), $events_label_plural_lowercase ); ?></p>
<?php
endif;
